/*
 * Module code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtQuick.h"

#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 32 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickpainteditem.sip"
#include <qquickpainteditem.h>
#line 38 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgabstractrenderer.sip"
#include <qsgabstractrenderer.h>
#line 41 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgimagenode.sip"
#include <qsgimagenode.h>
#line 44 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 165 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 47 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 52 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 58 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendererinterface.sip"
#include <qsgrendererinterface.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendernode.sip"
#include <qsgrendernode.h>
#line 66 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgsimpletexturenode.sip"
#include <qsgsimpletexturenode.h>
#line 69 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 72 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 75 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 78 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 81 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 98 "sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 84 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 87 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 90 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtextureprovider.sip"
#include <qsgtextureprovider.h>
#line 93 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 65 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 98 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 363 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 101 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 509 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 104 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 384 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 107 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 205 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 110 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 253 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 113 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 726 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 116 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 238 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 119 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 608 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 122 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 592 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 125 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 619 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 128 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 570 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 131 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 164 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 134 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 185 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 139 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickframebufferobject.sip"
#include <qquickframebufferobject.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickframebufferobject.sip"
#include <qquickframebufferobject.h>
#line 144 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "sip/QtGui/qopenglframebufferobject.sip"
#include <qopenglframebufferobject.h>
#line 147 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 150 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickframebufferobject.sip"
#include <qquickframebufferobject.h>
#line 153 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtexture.sip"
#include <qsgtexture.h>
#line 156 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickwindow.sip"
#include <qquickwindow.h>
#line 159 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtGui/qimage.sip"
#include <qimage.h>
#line 162 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtQml/qqmlengine.sip"
#include <qqmlengine.h>
#line 165 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtQml/qqmlengine.sip"
#include <qqmlengine.h>
#line 168 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 171 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 174 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickimageprovider.sip"
#include <qquickimageprovider.h>
#line 177 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 62 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickimageprovider.sip"
#include <qquickimageprovider.h>
#line 180 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 183 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 186 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 189 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 302 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 192 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 471 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 195 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 460 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 198 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 412 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 201 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 425 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 204 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 795 "sip/QtGui/qevent.sip"
#include <qevent.h>
#line 207 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtGui/qsurfaceformat.sip"
#include <qsurfaceformat.h>
#line 210 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtGui/qsurface.sip"
#include <qsurface.h>
#line 213 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 158 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 216 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 219 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgimagenode.sip"
#include <qsgimagenode.h>
#line 222 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 35 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 227 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtGui/qcolor.sip"
#include <qcolor.h>
#line 230 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendererinterface.sip"
#include <qsgrendererinterface.h>
#line 233 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendererinterface.sip"
#include <qsgrendererinterface.h>
#line 236 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendernode.sip"
#include <qsgrendernode.h>
#line 239 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendernode.sip"
#include <qsgrendernode.h>
#line 58 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendernode.sip"
#include <qsgrendernode.h>
#line 244 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgrendernode.sip"
#include <qsgrendernode.h>
#line 247 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 30 "sip/QtGui/qmatrix4x4.sip"
#include <qmatrix4x4.h>
#line 250 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 253 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "sip/QtGui/qregion.sip"
#include <qregion.h>
#line 256 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 44 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickimageprovider.sip"
#include <qquickimageprovider.h>
#line 259 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
#include <qquickitem.h>
#line 262 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickpainteditem.sip"
#include <qquickpainteditem.h>
#line 265 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickrendercontrol.sip"
#include <qquickrendercontrol.h>
#line 268 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickview.sip"
#include <qquickview.h>
#line 271 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickwindow.sip"
#include <qquickwindow.h>
#line 274 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgabstractrenderer.sip"
#include <qsgabstractrenderer.h>
#line 277 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgabstractrenderer.sip"
#include <qsgabstractrenderer.h>
#line 280 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgengine.sip"
#include <qsgengine.h>
#line 283 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgengine.sip"
#include <qsgengine.h>
#line 286 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgflatcolormaterial.sip"
#include <qsgflatcolormaterial.h>
#line 289 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsggeometry.sip"
#include <qsggeometry.h>
#line 55 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsggeometry.sip"
#include <qsggeometry.h>
#line 294 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsggeometry.sip"
#include <qsggeometry.h>
#line 237 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsggeometry.sip"
#include <qsggeometry.h>
#line 299 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsggeometry.sip"
#include <qsggeometry.h>
#line 248 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsggeometry.sip"
#include <qsggeometry.h>
#line 304 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsggeometry.sip"
#include <qsggeometry.h>
#line 261 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsggeometry.sip"
#include <qsggeometry.h>
#line 309 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 270 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 312 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 317 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 165 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
#include <qsgmaterial.h>
#line 320 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 58 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 325 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterialrhishader.sip"
#include <qsgmaterialrhishader.h>
#line 328 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 331 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 334 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 299 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 337 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 314 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 340 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 327 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
#include <qsgnode.h>
#line 343 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgsimplerectnode.sip"
#include <qsgsimplerectnode.h>
#line 346 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgsimpletexturenode.sip"
#include <qsgsimpletexturenode.h>
#line 349 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtexture.sip"
#include <qsgtexture.h>
#line 93 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtexture.sip"
#include <qsgtexture.h>
#line 354 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtexturematerial.sip"
#include <qsgtexturematerial.h>
#line 357 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 55 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgtexturematerial.sip"
#include <qsgtexturematerial.h>
#line 360 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgvertexcolormaterial.sip"
#include <qsgvertexcolormaterial.h>
#line 363 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtQuick[] = {
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'R', 'h', 'i', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'P', 'i', 'p', 'e', 'l', 'i', 'n', 'e', 'S', 't', 'a', 't', 'e', ':', ':', 'C', 'o', 'l', 'o', 'r', 'M', 'a', 's', 'k', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'R', 'h', 'i', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'P', 'i', 'p', 'e', 'l', 'i', 'n', 'e', 'S', 't', 'a', 't', 'e', ':', ':', 'B', 'l', 'e', 'n', 'd', 'F', 'a', 'c', 't', 'o', 'r', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'R', 'h', 'i', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'P', 'i', 'p', 'e', 'l', 'i', 'n', 'e', 'S', 't', 'a', 't', 'e', ':', ':', 'C', 'o', 'l', 'o', 'r', 'M', 'a', 's', 'k', 0,
    'Q', 'S', 'G', 'S', 'i', 'm', 'p', 'l', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'N', 'o', 'd', 'e', ':', ':', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 's', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'M', 'o', 'd', 'e', 0,
    'Q', 'S', 'G', 'S', 'i', 'm', 'p', 'l', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'N', 'o', 'd', 'e', ':', ':', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 's', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'F', 'l', 'a', 'g', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'R', 'h', 'i', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'P', 'i', 'p', 'e', 'l', 'i', 'n', 'e', 'S', 't', 'a', 't', 'e', ':', ':', 'C', 'u', 'l', 'l', 'M', 'o', 'd', 'e', 0,
    'Q', 'S', 'G', 'I', 'm', 'a', 'g', 'e', 'N', 'o', 'd', 'e', ':', ':', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 's', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'M', 'o', 'd', 'e', 0,
    'Q', 'S', 'G', 'I', 'm', 'a', 'g', 'e', 'N', 'o', 'd', 'e', ':', ':', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 's', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'F', 'l', 'a', 'g', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'm', 'p', 'i', 'l', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 's', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'm', 'p', 'i', 'l', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'R', 'h', 'i', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'P', 'i', 'p', 'e', 'l', 'i', 'n', 'e', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 't', 'e', ':', ':', 'D', 'i', 'r', 't', 'y', 'S', 't', 'a', 't', 'e', 's', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 't', 'e', ':', ':', 'D', 'i', 'r', 't', 'y', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'S', 'G', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', ':', ':', 'M', 'a', 't', 'r', 'i', 'x', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'S', 'G', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', ':', ':', 'M', 'a', 't', 'r', 'i', 'x', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'F', 'l', 'a', 'g', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'S', 'h', 'a', 'd', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 'T', 'y', 'p', 'e', 's', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'S', 'h', 'a', 'd', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'P', 'a', 'i', 'n', 't', 'e', 'd', 'I', 't', 'e', 'm', ':', ':', 'P', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 's', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'W', 'i', 'n', 'd', 'o', 'w', ':', ':', 'C', 'r', 'e', 'a', 't', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'P', 'a', 'i', 'n', 't', 'e', 'd', 'I', 't', 'e', 'm', ':', ':', 'P', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'A', 'p', 'i', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'R', 'h', 'i', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    'R', 'e', 'q', 'u', 'i', 'r', 'e', 's', 'F', 'u', 'l', 'l', 'M', 'a', 't', 'r', 'i', 'x', 'E', 'x', 'c', 'e', 'p', 't', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', '_', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', '2', 'D', 0,
    'Q', 'S', 'G', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', ':', ':', 'C', 'l', 'e', 'a', 'r', 'M', 'o', 'd', 'e', 'B', 'i', 't', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'W', 'i', 'n', 'd', 'o', 'w', ':', ':', 'C', 'r', 'e', 'a', 't', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'S', 'h', 'a', 'd', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', '_', 'C', 'o', 'l', 'o', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', '2', 'D', 0,
    'Q', 'S', 'G', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'C', 'r', 'e', 'a', 't', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'P', 'a', 'i', 'n', 't', 'e', 'd', 'I', 't', 'e', 'm', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'I', 't', 'e', 'm', ':', ':', 'U', 'p', 'd', 'a', 't', 'e', 'P', 'a', 'i', 'n', 't', 'N', 'o', 'd', 'e', 'D', 'a', 't', 'a', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 's', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'Q', 'S', 'G', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'C', 'r', 'e', 'a', 't', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'O', 'p', 't', 'i', 'o', 'n', 0,
    'Q', 'S', 'G', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', ':', ':', 'C', 'l', 'e', 'a', 'r', 'M', 'o', 'd', 'e', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'W', 'i', 'n', 'd', 'o', 'w', ':', ':', 'N', 'a', 't', 'i', 'v', 'e', 'O', 'b', 'j', 'e', 'c', 't', 'T', 'y', 'p', 'e', 0,
    'I', 't', 'e', 'm', 'D', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 'H', 'a', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 'v', 'e', 'r', 't', 'T', 'o', 'N', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'S', 'o', 'u', 'r', 'c', 'e', 'R', 'e', 'c', 't', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'N', 'o', 'd', 'e', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'W', 'i', 'n', 'd', 'o', 'w', ':', ':', 'S', 'c', 'e', 'n', 'e', 'G', 'r', 'a', 'p', 'h', 'E', 'r', 'r', 'o', 'r', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'r', 'o', 'm', 'N', 'a', 't', 'i', 'v', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'o', 'l', 'l', 'o', 'w', 's', 'I', 't', 'e', 'm', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'N', 'o', 'd', 'e', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 'F', 'l', 'a', 'g', 0,
    'U', 'p', 'd', 'a', 't', 'e', 's', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'P', 'i', 'p', 'e', 'l', 'i', 'n', 'e', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'S', 'G', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', ':', ':', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', '2', 'D', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'W', 'i', 'n', 'd', 'o', 'w', ':', ':', 'T', 'e', 'x', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'G', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', 'L', 'e', 'v', 'e', 'l', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'G', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'P', 'i', 'p', 'e', 'l', 'i', 'n', 'e', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'R', 'h', 'i', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'F', 'l', 'a', 'g', 's', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 's', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'D', 'a', 't', 'a', 'A', 's', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', '2', 'D', 0,
    'Q', 'S', 'G', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', ':', ':', 'C', 'o', 'l', 'o', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', '2', 'D', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'I', 't', 'e', 'm', ':', ':', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    'i', 'n', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'N', 'o', 'd', 'e', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'R', 'h', 'i', 'S', 'h', 'a', 'd', 'e', 'r', ':', ':', 'F', 'l', 'a', 'g', 0,
    'Q', 'S', 'G', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', ':', ':', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'T', 'y', 'p', 'e', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'D', 'a', 't', 'a', 'A', 's', 'C', 'o', 'l', 'o', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', '2', 'D', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'd', 'R', 'e', 'c', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    's', 'e', 't', 'P', 'e', 'r', 's', 'i', 's', 't', 'e', 'n', 't', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'I', 'n', 'v', 'e', 'r', 't', 'e', 'd', 'Y', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'e', 't', 'F', 'i', 'l', 't', 'e', 'r', 's', 'C', 'h', 'i', 'l', 'd', 'M', 'o', 'u', 's', 'e', 'E', 'v', 'e', 'n', 't', 's', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'I', 't', 'e', 'm', ':', ':', 'I', 't', 'e', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'D', 'a', 't', 'a', 0,
    'I', 't', 'e', 'm', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 'i', 'n', 'g', 'H', 'a', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'S', 'G', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'N', 'a', 't', 'i', 'v', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'N', 'o', 'd', 'e', ':', ':', 'S', 't', 'a', 't', 'e', 'F', 'l', 'a', 'g', 's', 0,
    'i', 's', 'C', 'a', 'c', 'h', 'e', 'd', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'D', 'a', 't', 'a', 'D', 'i', 'r', 't', 'y', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'C', 'o', 'l', 'o', 'r', 'e', 'd', 'R', 'e', 'c', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', '_', 'P', 'o', 'i', 'n', 't', '2', 'D', 0,
    'Q', 'S', 'G', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', ':', ':', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'S', 'e', 't', 0,
    's', 'e', 't', 'P', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'M', 'a', 't', 'r', 'i', 'x', 'T', 'o', 'R', 'e', 'c', 't', 0,
    'b', 'e', 'f', 'o', 'r', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'P', 'a', 's', 's', 'R', 'e', 'c', 'o', 'r', 'd', 'i', 'n', 'g', 0,
    'e', 'f', 'f', 'e', 'c', 't', 'i', 'v', 'e', 'D', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'W', 'i', 'n', 'd', 'o', 'w', ':', ':', 'R', 'e', 'n', 'd', 'e', 'r', 'S', 't', 'a', 'g', 'e', 0,
    'i', 's', 'P', 'e', 'r', 's', 'i', 's', 't', 'e', 'n', 't', 'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'I', 't', 'e', 'm', 'A', 'c', 't', 'i', 'v', 'e', 'F', 'o', 'c', 'u', 's', 'H', 'a', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'o', 'l', 'l', 'o', 'w', 's', 'I', 't', 'e', 'm', 'S', 'i', 'z', 'e', 0,
    'Q', 'S', 'G', 'O', 'p', 'a', 'q', 'u', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'i', 'z', 'e', 'd', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'S', 'u', 'b', 'R', 'e', 'c', 't', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'N', 'o', 'd', 'e', ':', ':', 'S', 't', 'a', 't', 'e', 'F', 'l', 'a', 'g', 0,
    'Q', 'S', 'G', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', ':', ':', 'D', 'r', 'a', 'w', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'Q', 'S', 'G', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', ':', ':', 'D', 'a', 't', 'a', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'a', 'f', 't', 'e', 'r', 'R', 'e', 'n', 'd', 'e', 'r', 'P', 'a', 's', 's', 'R', 'e', 'c', 'o', 'r', 'd', 'i', 'n', 'g', 0,
    'B', 'e', 'f', 'o', 'r', 'e', 'S', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 'z', 'i', 'n', 'g', 'S', 't', 'a', 'g', 'e', 0,
    'I', 't', 'e', 'm', 'C', 'l', 'i', 'p', 's', 'C', 'h', 'i', 'l', 'd', 'r', 'e', 'n', 'T', 'o', 'S', 'h', 'a', 'p', 'e', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'A', 's', 'y', 'n', 'c', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    'D', 'i', 'r', 't', 'y', 'C', 'a', 'c', 'h', 'e', 'd', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'D', 'a', 't', 'a', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'W', 'i', 't', 'h', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'T', 'y', 'p', 'e', 0,
    'i', 's', 'S', 'c', 'e', 'n', 'e', 'G', 'r', 'a', 'p', 'h', 'I', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'e', 'd', 0,
    'A', 'f', 't', 'e', 'r', 'S', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 'z', 'i', 'n', 'g', 'S', 't', 'a', 'g', 'e', 0,
    's', 'e', 't', 'P', 'e', 'r', 's', 'i', 's', 't', 'e', 'n', 't', 'S', 'c', 'e', 'n', 'e', 'G', 'r', 'a', 'p', 'h', 0,
    's', 'e', 't', 'C', 'l', 'e', 'a', 'r', 'B', 'e', 'f', 'o', 'r', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 0,
    'f', 'i', 'l', 't', 'e', 'r', 's', 'C', 'h', 'i', 'l', 'd', 'M', 'o', 'u', 's', 'e', 'E', 'v', 'e', 'n', 't', 's', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 'p', 't', 'e', 'd', 'M', 'o', 'u', 's', 'e', 'B', 'u', 't', 't', 'o', 'n', 's', 0,
    'm', 'i', 'r', 'r', 'o', 'r', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'l', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'F', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'Q', 'S', 'G', 'V', 'e', 'r', 't', 'e', 'x', 'C', 'o', 'l', 'o', 'r', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'S', 'h', 'a', 'd', 'i', 'n', 'g', 'L', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 0,
    'V', 'u', 'l', 'k', 'a', 'n', 'I', 'n', 's', 't', 'a', 'n', 'c', 'e', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'C', 'o', 'm', 'm', 'a', 'n', 'd', 'E', 'n', 'c', 'o', 'd', 'e', 'r', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'P', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'D', 'e', 'v', 'i', 'c', 'e', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'Q', 'S', 'G', 'N', 'o', 'd', 'e', ':', ':', 'D', 'i', 'r', 't', 'y', 'S', 't', 'a', 't', 'e', 'B', 'i', 't', 0,
    'Q', 'S', 'G', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', ':', ':', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'F', 'o', 'c', 'u', 's', 'I', 't', 'e', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'P', 'e', 'r', 's', 'i', 's', 't', 'e', 'n', 't', 'S', 'c', 'e', 'n', 'e', 'G', 'r', 'a', 'p', 'h', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'r', 'o', 'm', 'I', 'm', 'a', 'g', 'e', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'H', 'a', 's', 'A', 'l', 'p', 'h', 'a', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'V', 'i', 'e', 'w', ':', ':', 'R', 'e', 's', 'i', 'z', 'e', 'M', 'o', 'd', 'e', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 'm', 'e', 'n', 't', 'M', 'a', 's', 'k', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'I', 't', 'e', 'm', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'H', 'a', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'I', 't', 'e', 'm', 'C', 'h', 'i', 'l', 'd', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'I', 't', 'e', 'm', ':', ':', 'I', 't', 'e', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'I', 't', 'e', 'm', 'A', 'c', 'c', 'e', 'p', 't', 's', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'a', 'c', 't', 'o', 'r', 'y', 'F', 'o', 'r', 'I', 'm', 'a', 'g', 'e', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'o', 'l', 'l', 'o', 'w', 's', 'I', 't', 'e', 'm', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'Q', 'S', 'G', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'F', 'i', 'l', 't', 'e', 'r', 'i', 'n', 'g', 0,
    's', 'h', 'a', 'd', 'e', 'r', 'C', 'o', 'm', 'p', 'i', 'l', 'a', 't', 'i', 'o', 'n', 'T', 'y', 'p', 'e', 0,
    'D', 'e', 'v', 'i', 'c', 'e', 'C', 'o', 'n', 't', 'e', 'x', 't', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'O', 'p', 'e', 'n', 'G', 'L', 'C', 'o', 'n', 't', 'e', 'x', 't', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'h', 'i', 'l', 'd', 'N', 'o', 'd', 'e', 'B', 'e', 'f', 'o', 'r', 'e', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'C', 'o', 'n', 's', 't', 'a', 'n', 't', 'A', 'l', 'p', 'h', 'a', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'C', 'o', 'n', 's', 't', 'a', 'n', 't', 'C', 'o', 'l', 'o', 'r', 0,
    'b', 'e', 'g', 'i', 'n', 'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 's', 0,
    's', 'c', 'e', 'n', 'e', 'G', 'r', 'a', 'p', 'h', 'A', 'b', 'o', 'u', 't', 'T', 'o', 'S', 't', 'o', 'p', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'A', 'l', 'p', 'h', 'a', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'h', 'a', 's', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'A', 'l', 'p', 'h', 'a', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    's', 'c', 'e', 'n', 'e', 'G', 'r', 'a', 'p', 'h', 'I', 'n', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 'd', 0,
    's', 'c', 'e', 'n', 'e', 'G', 'r', 'a', 'p', 'h', 'I', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'e', 'd', 0,
    'c', 'h', 'i', 'l', 'd', 'M', 'o', 'u', 's', 'e', 'E', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'I', 't', 'e', 'm', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'H', 'a', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'I', 't', 'e', 'm', 'O', 'p', 'a', 'c', 'i', 't', 'y', 'H', 'a', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'I', 't', 'e', 'm', 'V', 'i', 's', 'i', 'b', 'l', 'e', 'H', 'a', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', 0,
    'Q', 'S', 'G', 'T', 'e', 'x', 't', 'u', 'r', 'e', ':', ':', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'Q', 'S', 'G', 'S', 'i', 'm', 'p', 'l', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'N', 'o', 'd', 'e', 0,
    'B', 'o', 'u', 'n', 'd', 'e', 'd', 'R', 'e', 'c', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 0,
    'C', 'o', 'm', 'm', 'a', 'n', 'd', 'Q', 'u', 'e', 'u', 'e', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'S', 'G', 'B', 'a', 's', 'i', 'c', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'N', 'o', 'd', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'h', 'i', 'l', 'd', 'N', 'o', 'd', 'e', 'A', 'f', 't', 'e', 'r', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'R', 'h', 'i', 'S', 'h', 'a', 'd', 'e', 'r', 0,
    's', 'e', 't', 'S', 'h', 'a', 'd', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 's', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'e', 'x', 'D', 'a', 't', 'a', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'Q', 'S', 'G', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', ':', ':', 'P', 'o', 'i', 'n', 't', '2', 'D', 0,
    'Q', 'S', 'G', 'F', 'l', 'a', 't', 'C', 'o', 'l', 'o', 'r', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'M', 'a', 't', 'r', 'i', 'x', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'F', 'l', 'i', 'p', 'Y', 0,
    's', 'e', 't', 'S', 'c', 'e', 'n', 'e', 'G', 'r', 'a', 'p', 'h', 'B', 'a', 'c', 'k', 'e', 'n', 'd', 0,
    'B', 'e', 'f', 'o', 'r', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 'S', 't', 'a', 'g', 'e', 0,
    'o', 'p', 'e', 'n', 'g', 'l', 'C', 'o', 'n', 't', 'e', 'x', 't', 'C', 'r', 'e', 'a', 't', 'e', 'd', 0,
    'c', 'l', 'e', 'a', 'r', 'B', 'e', 'f', 'o', 'r', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'O', 'w', 'n', 's', 'G', 'L', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'S', 'i', 'z', 'e', 'R', 'o', 'o', 't', 'O', 'b', 'j', 'e', 'c', 't', 'T', 'o', 'V', 'i', 'e', 'w', 0,
    'S', 'i', 'z', 'e', 'V', 'i', 'e', 'w', 'T', 'o', 'R', 'o', 'o', 't', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'S', 'c', 'a', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'B', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'R', 'e', 'c', 't', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'I', 't', 'e', 'm', 'G', 'r', 'a', 'b', 'R', 'e', 's', 'u', 'l', 't', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 'p', 't', 'T', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', 's', 0,
    'n', 'e', 'x', 't', 'I', 't', 'e', 'm', 'I', 'n', 'F', 'o', 'c', 'u', 's', 'C', 'h', 'a', 'i', 'n', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 'p', 't', 'H', 'o', 'v', 'e', 'r', 'E', 'v', 'e', 'n', 't', 's', 0,
    'a', 'c', 'c', 'e', 'p', 't', 'e', 'd', 'M', 'o', 'u', 's', 'e', 'B', 'u', 't', 't', 'o', 'n', 's', 0,
    'I', 't', 'e', 'm', 'P', 'a', 'r', 'e', 'n', 't', 'H', 'a', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'I', 't', 'e', 'm', 'C', 'h', 'i', 'l', 'd', 'A', 'd', 'd', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'i', 'n', 'c', 'u', 'b', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'r', 0,
    's', 'e', 't', 'I', 'n', 'i', 't', 'i', 'a', 'l', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', 0,
    's', 'e', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'D', 'e', 'p', 't', 'h', 'A', 'w', 'a', 'r', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 0,
    'C', 'o', 'm', 'm', 'a', 'n', 'd', 'L', 'i', 's', 't', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'A', 'l', 'l', 'C', 'h', 'i', 'l', 'd', 'N', 'o', 'd', 'e', 's', 0,
    'Q', 'S', 'G', 'N', 'o', 'd', 'e', ':', ':', 'D', 'i', 'r', 't', 'y', 'S', 't', 'a', 't', 'e', 0,
    'R', 'e', 'q', 'u', 'i', 'r', 'e', 's', 'D', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 'n', 't', 0,
    's', 'e', 't', 'S', 'h', 'a', 'd', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'D', 'a', 't', 'a', 'A', 's', 'P', 'o', 'i', 'n', 't', '2', 'D', 0,
    'm', 'a', 'r', 'k', 'V', 'e', 'r', 't', 'e', 'x', 'D', 'a', 't', 'a', 'D', 'i', 'r', 't', 'y', 0,
    's', 'e', 't', 'I', 'n', 'd', 'e', 'x', 'D', 'a', 't', 'a', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'A', 'l', 'w', 'a', 'y', 's', 'U', 'p', 'l', 'o', 'a', 'd', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    's', 'e', 't', 'P', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'Q', 'S', 'G', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 0,
    'e', 'n', 'd', 'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 's', 0,
    'N', 'a', 't', 'i', 'v', 'e', 'O', 'b', 'j', 'e', 'c', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'N', 'a', 't', 'i', 'v', 'e', 'T', 'e', 'x', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 'N', 'o', 'd', 'e', 0,
    'A', 'f', 't', 'e', 'r', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 'S', 't', 'a', 'g', 'e', 0,
    'C', 'o', 'n', 't', 'e', 'x', 't', 'N', 'o', 't', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'b', 'e', 'f', 'o', 'r', 'e', 'S', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 'z', 'i', 'n', 'g', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'r', 'o', 'm', 'I', 'd', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'R', 'e', 'n', 'd', 'e', 'r', 'C', 'o', 'n', 't', 'r', 'o', 'l', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'P', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 's', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'F', 'o', 'c', 'u', 's', 'O', 'n', 'T', 'a', 'b', 0,
    'i', 's', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'e', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'I', 'm', 'a', 'g', 'e', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'I', 'm', 'a', 'g', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    's', 'e', 't', 'M', 'i', 'r', 'r', 'o', 'r', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'l', 'y', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'Q', 'u', 'i', 'c', 'k', 'I', 't', 'e', 'm', '*', '>', 0,
    'Q', 'S', 'G', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    'Q', 'S', 'G', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    's', 'e', 't', 'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', 'L', 'e', 'v', 'e', 'l', 0,
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'S', 'h', 'a', 'd', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'O', 'f', 'f', 'l', 'i', 'n', 'e', 'C', 'o', 'm', 'p', 'i', 'l', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'u', 'n', 't', 'i', 'm', 'e', 'C', 'o', 'm', 'p', 'i', 'l', 'a', 't', 'i', 'o', 'n', 0,
    'R', 'e', 'n', 'd', 'e', 'r', 'P', 'a', 's', 's', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'O', 'w', 'n', 's', 'O', 'p', 'a', 'q', 'u', 'e', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'S', 'a', 'm', 'p', 'l', 'e', 'd', 'I', 'm', 'a', 'g', 'e', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', ':', ':', 'F', 'l', 'a', 'g', 's', 0,
    'R', 'e', 'q', 'u', 'i', 'r', 'e', 's', 'F', 'u', 'l', 'l', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'M', 'i', 'r', 'r', 'o', 'r', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'l', 'y', 0,
    's', 'e', 't', 'M', 'i', 'p', 'm', 'a', 'p', 'F', 'i', 'l', 't', 'e', 'r', 'i', 'n', 'g', 0,
    'T', 'e', 'x', 'C', 'o', 'o', 'r', 'd', '2', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'T', 'e', 'x', 'C', 'o', 'o', 'r', 'd', '1', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'm', 'a', 'r', 'k', 'I', 'n', 'd', 'e', 'x', 'D', 'a', 't', 'a', 'D', 'i', 'r', 't', 'y', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'R', 'e', 'c', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'i', 's', 'V', 'e', 'r', 't', 'e', 'x', 'C', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 0,
    'C', 'l', 'e', 'a', 'r', 'S', 't', 'e', 'n', 'c', 'i', 'l', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'a', 'f', 't', 'e', 'r', 'S', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 'z', 'i', 'n', 'g', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'a', 'n', 'U', 's', 'e', 'A', 't', 'l', 'a', 's', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'V', 'i', 'e', 'w', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'T', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'a', 'i', 'n', 'm', 'e', 'n', 't', 'M', 'a', 's', 'k', 0,
    's', 'e', 't', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    's', 'e', 't', 'P', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 0,
    'Q', 'S', 'G', 'D', 'y', 'n', 'a', 'm', 'i', 'c', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'B', 'i', 'n', 'd', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'S', 'G', 'S', 'i', 'm', 'p', 'l', 'e', 'R', 'e', 'c', 't', 'N', 'o', 'd', 'e', 0,
    'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'O', 'p', 'a', 'q', 'u', 'e', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'N', 'o', 'd', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'G', 'N', 'o', 'd', 'e', ':', ':', 'N', 'o', 'd', 'e', 'T', 'y', 'p', 'e', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'U', 'n', 'i', 'f', 'o', 'r', 'm', 'D', 'a', 't', 'a', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'S', 'r', 'c', '1', 'A', 'l', 'p', 'h', 'a', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'S', 'r', 'c', '1', 'C', 'o', 'l', 'o', 'r', 0,
    'S', 'u', 'p', 'p', 'o', 'r', 't', 's', 'R', 'h', 'i', 'S', 'h', 'a', 'd', 'e', 'r', 0,
    'C', 'u', 's', 't', 'o', 'm', 'C', 'o', 'm', 'p', 'i', 'l', 'e', 'S', 't', 'e', 'p', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', ':', ':', 'F', 'l', 'a', 'g', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'S', 'h', 'a', 'd', 'e', 'r', 0,
    'U', 'n', 's', 'i', 'g', 'n', 'e', 'd', 'S', 'h', 'o', 'r', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'G', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', ':', ':', 'T', 'y', 'p', 'e', 0,
    'D', 'r', 'a', 'w', 'T', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 'S', 't', 'r', 'i', 'p', 0,
    'T', 'e', 'x', 'C', 'o', 'o', 'r', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'i', 'n', 'd', 'e', 'x', 'D', 'a', 't', 'a', 'A', 's', 'U', 'S', 'h', 'o', 'r', 't', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'D', 'a', 't', 'a', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'G', 'L', '_', 'T', 'R', 'I', 'A', 'N', 'G', 'L', 'E', '_', 'S', 'T', 'R', 'I', 'P', 0,
    's', 'c', 'e', 'n', 'e', 'G', 'r', 'a', 'p', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    's', 'c', 'e', 'n', 'e', 'G', 'r', 'a', 'p', 'h', 'B', 'a', 'c', 'k', 'e', 'n', 'd', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    's', 'c', 'h', 'e', 'd', 'u', 'l', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'J', 'o', 'b', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'H', 'a', 's', 'M', 'i', 'p', 'm', 'a', 'p', 's', 0,
    'r', 'e', 's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'O', 'p', 'a', 'q', 'u', 'e', 'P', 'a', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'P', 'a', 'i', 'n', 't', 'e', 'd', 'I', 't', 'e', 'm', 0,
    'a', 'c', 'c', 'e', 'p', 't', 'T', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', 's', 0,
    'r', 'e', 's', 'e', 't', 'A', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 'i', 'n', 'g', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'I', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'u', 'n', 'g', 'r', 'a', 'b', 'T', 'o', 'u', 'c', 'h', 'P', 'o', 'i', 'n', 't', 's', 0,
    'a', 'c', 'c', 'e', 'p', 't', 'H', 'o', 'v', 'e', 'r', 'E', 'v', 'e', 'n', 't', 's', 0,
    's', 'e', 't', 'I', 'm', 'p', 'l', 'i', 'c', 'i', 't', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'l', 'i', 'n', 'e', 'O', 'f', 'f', 's', 'e', 't', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'I', 't', 'e', 'm', ':', ':', 'F', 'l', 'a', 'g', 's', 0,
    'i', 's', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    'f', 'r', 'a', 'm', 'e', 'b', 'u', 'f', 'f', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'C', 'o', 'm', 'p', 'l', 'e', 't', 'e', 0,
    'm', 'o', 'u', 's', 'e', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'W', 'r', 'a', 'p', 'M', 'o', 'd', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'd', 'F', 'r', 'o', 'm', 'A', 't', 'l', 'a', 's', 0,
    'i', 'n', 'h', 'e', 'r', 'i', 't', 'e', 'd', 'O', 'p', 'a', 'c', 'i', 't', 'y', 0,
    's', 'h', 'a', 'd', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'G', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 'N', 'o', 'd', 'e', 0,
    'Q', 'S', 'G', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'N', 'o', 'd', 'e', 0,
    's', 'e', 't', 'I', 's', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'u', 'l', 'a', 'r', 0,
    'i', 's', 'S', 'u', 'b', 't', 'r', 'e', 'e', 'B', 'l', 'o', 'c', 'k', 'e', 'd', 0,
    'p', 'r', 'e', 'p', 'e', 'n', 'd', 'C', 'h', 'i', 'l', 'd', 'N', 'o', 'd', 'e', 0,
    'D', 'i', 'r', 't', 'y', 'N', 'o', 'd', 'e', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'N', 'o', 'd', 'e', 'T', 'y', 'p', 'e', 0,
    'S', 'r', 'c', 'A', 'l', 'p', 'h', 'a', 'S', 'a', 't', 'u', 'r', 'a', 't', 'e', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'D', 's', 't', 'A', 'l', 'p', 'h', 'a', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'S', 'r', 'c', 'A', 'l', 'p', 'h', 'a', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'D', 's', 't', 'C', 'o', 'l', 'o', 'r', 0,
    'O', 'n', 'e', 'M', 'i', 'n', 'u', 's', 'S', 'r', 'c', 'C', 'o', 'l', 'o', 'r', 0,
    'U', 'n', 's', 'i', 'g', 'n', 'e', 'd', 'B', 'y', 't', 'e', 'T', 'y', 'p', 'e', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'i', 'n', 'd', 'e', 'x', 'D', 'a', 't', 'a', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'C', 'l', 'e', 'a', 'r', 'D', 'e', 'p', 't', 'h', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'C', 'l', 'e', 'a', 'r', 'C', 'o', 'l', 'o', 'r', 'B', 'u', 'f', 'f', 'e', 'r', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'C', 'l', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'e', 's', 'e', 't', 'O', 'p', 'e', 'n', 'G', 'L', 'S', 't', 'a', 't', 'e', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'S', 'i', 'z', 'e', 0,
    'm', 'o', 'u', 's', 'e', 'G', 'r', 'a', 'b', 'b', 'e', 'r', 'I', 't', 'e', 'm', 0,
    'f', 'i', 'l', 'l', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 'S', 'c', 'a', 'l', 'e', 0,
    'p', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 'H', 'i', 'n', 't', 's', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'F', 'o', 'c', 'u', 's', 'O', 'n', 'T', 'a', 'b', 0,
    't', 'o', 'u', 'c', 'h', 'U', 'n', 'g', 'r', 'a', 'b', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'o', 'u', 's', 'e', 'U', 'n', 'g', 'r', 'a', 'b', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'Q', 'u', 'e', 'r', 'y', 0,
    'f', 'o', 'r', 'c', 'e', 'A', 'c', 't', 'i', 'v', 'e', 'F', 'o', 'c', 'u', 's', 0,
    'm', 'a', 'p', 'R', 'e', 'c', 't', 'F', 'r', 'o', 'm', 'S', 'c', 'e', 'n', 'e', 0,
    's', 'e', 't', 'K', 'e', 'e', 'p', 'T', 'o', 'u', 'c', 'h', 'G', 'r', 'a', 'b', 0,
    's', 'e', 't', 'K', 'e', 'e', 'p', 'M', 'o', 'u', 's', 'e', 'G', 'r', 'a', 'b', 0,
    's', 'e', 't', 'I', 'm', 'p', 'l', 'i', 'c', 'i', 't', 'W', 'i', 'd', 't', 'h', 0,
    'I', 't', 'e', 'm', 'A', 'c', 'c', 'e', 'p', 't', 's', 'D', 'r', 'o', 'p', 's', 0,
    'I', 't', 'e', 'm', 'I', 's', 'F', 'o', 'c', 'u', 's', 'S', 'c', 'o', 'p', 'e', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'I', 't', 'e', 'm', ':', ':', 'F', 'l', 'a', 'g', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'B', 'y', 't', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'm', 'i', 'r', 'r', 'o', 'r', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'l', 'y', 0,
    'r', 'e', 'l', 'e', 'a', 's', 'e', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 's', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'a', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', 'L', 'e', 'v', 'e', 'l', 0,
    'O', 'p', 'a', 'q', 'u', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 0,
    'P', 'a', 'i', 'n', 't', 'e', 'r', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'S', 'i', 'b', 'l', 'i', 'n', 'g', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 'C', 'h', 'i', 'l', 'd', 'N', 'o', 'd', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'h', 'i', 'l', 'd', 'N', 'o', 'd', 'e', 0,
    'O', 'p', 'a', 'c', 'i', 't', 'y', 'N', 'o', 'd', 'e', 'T', 'y', 'p', 'e', 0,
    'R', 'h', 'i', 'S', 'h', 'a', 'd', 'e', 'r', 'W', 'a', 'n', 't', 'e', 'd', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'T', 'y', 'p', 'e', 0,
    'm', 'o', 'd', 'e', 'l', 'V', 'i', 'e', 'w', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'r', 'e', 'b', 'u', 'i', 'l', 'd', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'm', 'i', 'p', 'm', 'a', 'p', 'F', 'i', 'l', 't', 'e', 'r', 'i', 'n', 'g', 0,
    'Q', 'S', 'G', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'N', 'o', 'd', 'e', 0,
    'U', 'n', 's', 'i', 'g', 'n', 'e', 'd', 'I', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'D', 'r', 'a', 'w', 'T', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 'F', 'a', 'n', 0,
    'i', 'n', 'd', 'e', 'x', 'D', 'a', 't', 'a', 'A', 's', 'U', 'I', 'n', 't', 0,
    'G', 'L', '_', 'T', 'R', 'I', 'A', 'N', 'G', 'L', 'E', '_', 'F', 'A', 'N', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'R', 'e', 'c', 't', 0,
    'Q', 't', 'T', 'e', 'x', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'I', 'm', 'a', 'g', 'e', 'N', 'o', 'd', 'e', 0,
    's', 'c', 'e', 'n', 'e', 'G', 'r', 'a', 'p', 'h', 'E', 'r', 'r', 'o', 'r', 0,
    'b', 'e', 'f', 'o', 'r', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'F', 'o', 'c', 'u', 's', 'I', 't', 'e', 'm', 0,
    'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 's', 'O', 'p', 'a', 'q', 'u', 'e', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'W', 'i', 'n', 'd', 'o', 'w', 'F', 'o', 'r', 0,
    's', 'e', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 0,
    'F', 'a', 's', 't', 'F', 'B', 'O', 'R', 'e', 's', 'i', 'z', 'i', 'n', 'g', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 'm', 'e', 'n', 't', 'M', 'a', 's', 'k', 0,
    'h', 'o', 'v', 'e', 'r', 'L', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'h', 'o', 'v', 'e', 'r', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'a', 'p', 'R', 'e', 'c', 't', 'F', 'r', 'o', 'm', 'I', 't', 'e', 'm', 0,
    's', 'c', 'o', 'p', 'e', 'd', 'F', 'o', 'c', 'u', 's', 'I', 't', 'e', 'm', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'O', 'r', 'i', 'g', 'i', 'n', 0,
    'I', 't', 'e', 'm', 'S', 'c', 'e', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'I', 't', 'e', 'm', 'H', 'a', 's', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'P', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'P', 'a', 'i', 'n', 't', 'N', 'o', 'd', 'e', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'k', 'e', 'y', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 'a', 's', 'A', 'l', 'p', 'h', 'a', 'C', 'h', 'a', 'n', 'n', 'e', 'l', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', 'N', 'o', 'n', 'e', 0,
    'i', 's', 'A', 't', 'l', 'a', 's', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    's', 't', 'e', 'n', 'c', 'i', 'l', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'c', 'i', 's', 's', 'o', 'r', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'S', 'h', 'a', 'd', 'e', 'r', 'B', 'y', 't', 'e', 'C', 'o', 'd', 'e', 0,
    'Q', 'S', 'G', 'O', 'p', 'a', 'c', 'i', 't', 'y', 'N', 'o', 'd', 'e', 0,
    'o', 'p', 'a', 'q', 'u', 'e', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'D', 'i', 'r', 't', 'y', 'N', 'o', 'd', 'e', 'A', 'd', 'd', 'e', 'd', 0,
    'Q', 'S', 'G', 'N', 'o', 'd', 'e', ':', ':', 'F', 'l', 'a', 'g', 's', 0,
    'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'S', 'h', 'a', 'd', 'e', 'r', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'N', 'a', 'm', 'e', 's', 0,
    'c', 'o', 'm', 'b', 'i', 'n', 'e', 'd', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'i', 's', 'O', 'p', 'a', 'c', 'i', 't', 'y', 'D', 'i', 'r', 't', 'y', 0,
    's', 'e', 't', 'O', 'w', 'n', 's', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'C', 'o', 'l', 'o', 'r', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'D', 'r', 'a', 'w', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'D', 'y', 'n', 'a', 'm', 'i', 'c', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    't', 'e', 'x', 't', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'A', 'f', 't', 'e', 'r', 'S', 'w', 'a', 'p', 'S', 't', 'a', 'g', 'e', 0,
    'a', 'f', 't', 'e', 'r', 'A', 'n', 'i', 'm', 'a', 't', 'i', 'n', 'g', 0,
    'a', 'f', 't', 'e', 'r', 'R', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'I', 'd', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'S', 'i', 'z', 'e', 0,
    'o', 'p', 'a', 'q', 'u', 'e', 'P', 'a', 'i', 'n', 't', 'i', 'n', 'g', 0,
    'd', 'r', 'a', 'g', 'L', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'r', 'a', 'g', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'h', 'o', 'v', 'e', 'r', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'a', 'p', 'R', 'e', 'c', 't', 'T', 'o', 'S', 'c', 'e', 'n', 'e', 0,
    'h', 'a', 's', 'A', 'c', 't', 'i', 'v', 'e', 'F', 'o', 'c', 'u', 's', 0,
    'i', 'm', 'p', 'l', 'i', 'c', 'i', 't', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'b', 'a', 's', 'e', 'l', 'i', 'n', 'e', 'O', 'f', 'f', 's', 'e', 't', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 0,
    'm', 'o', 'u', 's', 'e', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'M', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 'R', 'e', 'p', 'e', 'a', 't', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'c', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'K', 'e', 'y', 0,
    'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', '1', '6', 'x', 0,
    'c', 'h', 'a', 'n', 'g', 'e', 'd', 'S', 't', 'a', 't', 'e', 's', 0,
    'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'S', 't', 'a', 't', 'e', 0,
    'Q', 'S', 'G', 'R', 'e', 'n', 'd', 'e', 'r', 'N', 'o', 'd', 'e', 0,
    'i', 's', 'A', 'p', 'i', 'R', 'h', 'i', 'B', 'a', 's', 'e', 'd', 0,
    'D', 'i', 'r', 'e', 'c', 't', '3', 'D', '1', '1', 'R', 'h', 'i', 0,
    'i', 's', 'R', 'e', 'c', 't', 'a', 'n', 'g', 'u', 'l', 'a', 'r', 0,
    'D', 'i', 'r', 't', 'y', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'D', 'i', 'r', 't', 'y', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'U', 's', 'e', 'P', 'r', 'e', 'p', 'r', 'o', 'c', 'e', 's', 's', 0,
    'O', 'w', 'n', 'e', 'd', 'B', 'y', 'P', 'a', 'r', 'e', 'n', 't', 0,
    'Q', 'S', 'G', 'N', 'o', 'd', 'e', ':', ':', 'F', 'l', 'a', 'g', 0,
    'B', 'a', 's', 'i', 'c', 'N', 'o', 'd', 'e', 'T', 'y', 'p', 'e', 0,
    'i', 's', 'M', 'a', 't', 'r', 'i', 'x', 'D', 'i', 'r', 't', 'y', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'R', 'e', 'c', 't', 0,
    'D', 'r', 'a', 'w', 'T', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 's', 0,
    'D', 'r', 'a', 'w', 'L', 'i', 'n', 'e', 'S', 't', 'r', 'i', 'p', 0,
    'S', 't', 'a', 't', 'i', 'c', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'S', 't', 'r', 'e', 'a', 'm', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'T', 'y', 'p', 'e', 0,
    'G', 'L', '_', 'L', 'I', 'N', 'E', '_', 'S', 'T', 'R', 'I', 'P', 0,
    's', 'e', 't', 'C', 'l', 'e', 'a', 'r', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'D', 'e', 'v', 'i', 'c', 'e', 'R', 'e', 'c', 't', 0,
    'o', 'p', 'e', 'n', 'g', 'l', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    's', 'e', 't', 'R', 'e', 's', 'i', 'z', 'e', 'M', 'o', 'd', 'e', 0,
    'p', 'r', 'e', 'p', 'a', 'r', 'e', 'T', 'h', 'r', 'e', 'a', 'd', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'S', 'c', 'a', 'l', 'e', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'r', 'a', 'g', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'N', 'o', 'd', 'e', 0,
    'm', 'a', 'p', 'R', 'e', 'c', 't', 'T', 'o', 'I', 't', 'e', 'm', 0,
    'k', 'e', 'e', 'p', 'T', 'o', 'u', 'c', 'h', 'G', 'r', 'a', 'b', 0,
    'k', 'e', 'e', 'p', 'M', 'o', 'u', 's', 'e', 'G', 'r', 'a', 'b', 0,
    'i', 'm', 'p', 'l', 'i', 'c', 'i', 't', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'P', 'a', 'r', 'e', 'n', 't', 'I', 't', 'e', 'm', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'P', 'i', 'x', 'm', 'a', 'p', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    's', 't', 'a', 't', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'k', 'e', 'y', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'a', 'p', 'F', 'r', 'o', 'm', 'G', 'l', 'o', 'b', 'a', 'l', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'Q', 'u', 'i', 'c', 'k', 0,
    'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', '8', 'x', 0,
    'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', '4', 'x', 0,
    'A', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', '2', 'x', 0,
    's', 't', 'e', 'n', 'c', 'i', 'l', 'V', 'a', 'l', 'u', 'e', 0,
    'S', 'c', 'i', 's', 's', 'o', 'r', 'S', 't', 'a', 't', 'e', 0,
    'S', 't', 'e', 'n', 'c', 'i', 'l', 'S', 't', 'a', 't', 'e', 0,
    'c', 'h', 'i', 'l', 'd', 'A', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'O', 'w', 'n', 's', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'O', 'w', 'n', 's', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'C', 'l', 'i', 'p', 'N', 'o', 'd', 'e', 'T', 'y', 'p', 'e', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'S', 'h', 'a', 'd', 'e', 'r', 0,
    's', 'e', 't', 'F', 'i', 'l', 't', 'e', 'r', 'i', 'n', 'g', 0,
    'Q', 'S', 'G', 'I', 'm', 'a', 'g', 'e', 'N', 'o', 'd', 'e', 0,
    'D', 'r', 'a', 'w', 'L', 'i', 'n', 'e', 'L', 'o', 'o', 'p', 0,
    's', 'i', 'z', 'e', 'O', 'f', 'V', 'e', 'r', 't', 'e', 'x', 0,
    'G', 'L', '_', 'T', 'R', 'I', 'A', 'N', 'G', 'L', 'E', 'S', 0,
    'G', 'L', '_', 'L', 'I', 'N', 'E', '_', 'L', 'O', 'O', 'P', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'S', 'h', 'a', 'd', 'e', 'r', 0,
    's', 'e', 't', 'C', 'l', 'e', 'a', 'r', 'M', 'o', 'd', 'e', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'R', 'e', 'c', 't', 0,
    'c', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    't', 'e', 'x', 't', 'D', 'o', 'c', 'u', 'm', 'e', 'n', 't', 0,
    's', 'c', 'e', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 0,
    's', 'e', 't', 'F', 'i', 'l', 'l', 'C', 'o', 'l', 'o', 'r', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 'S', 'i', 'z', 'e', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'P', 'o', 'l', 'i', 's', 'h', 0,
    'm', 'a', 'p', 'F', 'r', 'o', 'm', 'S', 'c', 'e', 'n', 'e', 0,
    'i', 's', 'F', 'o', 'c', 'u', 's', 'S', 'c', 'o', 'p', 'e', 0,
    'a', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 'i', 'n', 'g', 0,
    'c', 'h', 'i', 'l', 'd', 'r', 'e', 'n', 'R', 'e', 'c', 't', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'I', 'm', 'a', 'g', 'e', 0,
    'f', 'o', 'c', 'u', 's', 'I', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'A', 'n', 'c', 'e', 's', 't', 'o', 'r', 'O', 'f', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 'W', 'i', 'd', 't', 'h', 0,
    'D', 'i', 'r', 't', 'y', 'O', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'f', 'r', 'a', 'm', 'e', 'S', 'w', 'a', 'p', 'p', 'e', 'd', 0,
    's', 'c', 'i', 's', 's', 'o', 'r', 'R', 'e', 'c', 't', 0,
    'g', 'e', 't', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'g', 'r', 'a', 'p', 'h', 'i', 'c', 's', 'A', 'p', 'i', 0,
    'R', 'h', 'i', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'Q', 'S', 'G', 'C', 'l', 'i', 'p', 'N', 'o', 'd', 'e', 0,
    's', 'e', 't', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'n', 'e', 'x', 't', 'S', 'i', 'b', 'l', 'i', 'n', 'g', 0,
    'u', 'n', 'i', 'f', 'o', 'r', 'm', 'D', 'a', 't', 'a', 0,
    'd', 'i', 'r', 't', 'y', 'S', 't', 'a', 't', 'e', 's', 0,
    'D', 'i', 'r', 't', 'y', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'o', 'w', 'n', 's', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'N', 'o', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    's', 'i', 'z', 'e', 'O', 'f', 'I', 'n', 'd', 'e', 'x', 0,
    'd', 'r', 'a', 'w', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'C', 'o', 'u', 'n', 't', 0,
    'Q', 'S', 'G', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'Q', 'S', 'G', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'S', 'c', 'e', 'n', 'e', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'I', 't', 'e', 'm', 0,
    'i', 'n', 'i', 't', 'i', 'a', 'l', 'S', 'i', 'z', 'e', 0,
    'p', 'o', 'l', 'i', 's', 'h', 'I', 't', 'e', 'm', 's', 0,
    'g', 'r', 'a', 'b', 'T', 'o', 'I', 'm', 'a', 'g', 'e', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'V', 'a', 'l', 'i', 'd', 0,
    'm', 'a', 'p', 'F', 'r', 'o', 'm', 'I', 't', 'e', 'm', 0,
    'u', 'n', 'g', 'r', 'a', 'b', 'M', 'o', 'u', 's', 'e', 0,
    's', 'e', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'r', 'e', 's', 'e', 't', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 't', 'a', 'c', 'k', 'B', 'e', 'f', 'o', 'r', 'e', 0,
    'B', 'o', 't', 't', 'o', 'm', 'R', 'i', 'g', 'h', 't', 0,
    's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 'z', 'e', 0,
    'r', 'o', 'o', 't', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    't', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', 0,
    'u', 'n', 's', 'e', 't', 'C', 'u', 'r', 's', 'o', 'r', 0,
    'm', 'a', 'p', 'T', 'o', 'G', 'l', 'o', 'b', 'a', 'l', 0,
    's', 'e', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'e', 'x', 'p', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'E', 'v', 'e', 'n', 't', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'S', 'i', 'z', 'e', 0,
    'C', 'l', 'a', 'm', 'p', 'T', 'o', 'E', 'd', 'g', 'e', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 'n', 't', 0,
    's', 'e', 't', 'C', 'l', 'i', 'p', 'R', 'e', 'c', 't', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'e', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'S', 't', 'a', 't', 'e', 0,
    'h', 'a', 's', 'M', 'i', 'p', 'm', 'a', 'p', 's', 0,
    'Q', 'S', 'G', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'B', 'l', 'e', 'n', 'd', 'S', 't', 'a', 't', 'e', 0,
    'C', 'o', 'l', 'o', 'r', 'S', 't', 'a', 't', 'e', 0,
    'D', 'e', 'p', 't', 'h', 'S', 't', 'a', 't', 'e', 0,
    'D', 'i', 'r', 'e', 'c', 't', '3', 'D', '1', '2', 0,
    'p', 'r', 'e', 'p', 'r', 'o', 'c', 'e', 's', 's', 0,
    'f', 'i', 'r', 's', 't', 'C', 'h', 'i', 'l', 'd', 0,
    'c', 'h', 'i', 'l', 'd', 'C', 'o', 'u', 'n', 't', 0,
    'd', 'e', 'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 0,
    'D', 'o', 'u', 'b', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'B', 'y', 't', 'e', 's', '4', 'T', 'y', 'p', 'e', 0,
    'B', 'y', 't', 'e', 's', '3', 'T', 'y', 'p', 'e', 0,
    'B', 'y', 't', 'e', 's', '2', 'T', 'y', 'p', 'e', 0,
    'D', 'r', 'a', 'w', 'P', 'o', 'i', 'n', 't', 's', 0,
    'v', 'e', 'r', 't', 'e', 'x', 'D', 'a', 't', 'a', 0,
    'i', 'n', 'd', 'e', 'x', 'C', 'o', 'u', 'n', 't', 0,
    'i', 's', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'c', 'l', 'e', 'a', 'r', 'C', 'o', 'l', 'o', 'r', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'R', 'e', 'c', 't', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'M', 'o', 'd', 'e', 0,
    'r', 'o', 'o', 't', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'V', 'i', 'e', 'w', 0,
    's', 'a', 'v', 'e', 'T', 'o', 'F', 'i', 'l', 'e', 0,
    't', 'a', 'r', 'g', 'e', 't', 'S', 'i', 'z', 'e', 0,
    'w', 'i', 'd', 't', 'h', 'V', 'a', 'l', 'i', 'd', 0,
    'i', 't', 'e', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'm', 'a', 'p', 'T', 'o', 'S', 'c', 'e', 'n', 'e', 0,
    'r', 'e', 's', 'e', 't', 'W', 'i', 'd', 't', 'h', 0,
    'c', 'h', 'i', 'l', 'd', 'I', 't', 'e', 'm', 's', 0,
    's', 't', 'a', 'c', 'k', 'A', 'f', 't', 'e', 'r', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'I', 't', 'e', 'm', 0,
    'B', 'o', 't', 't', 'o', 'm', 'L', 'e', 'f', 't', 0,
    'Q', 'Q', 'u', 'i', 'c', 'k', 'I', 't', 'e', 'm', 0,
    'c', 'l', 'a', 's', 's', 'B', 'e', 'g', 'i', 'n', 0,
    't', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', 0,
    'w', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'g', 'r', 'a', 'b', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'c', 'l', 'i', 'p', 'R', 'e', 'g', 'i', 'o', 'n', 0,
    's', 'e', 't', 'O', 'p', 'a', 'c', 'i', 't', 'y', 0,
    's', 'h', 'a', 'd', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'R', 'e', 'c', 't', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 'n', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'C', 'u', 'l', 'l', 'S', 't', 'a', 't', 'e', 0,
    'V', 'u', 'l', 'k', 'a', 'n', 'R', 'h', 'i', 0,
    'O', 'p', 'e', 'n', 'G', 'L', 'R', 'h', 'i', 0,
    'm', 'a', 'r', 'k', 'D', 'i', 'r', 't', 'y', 0,
    'l', 'a', 's', 't', 'C', 'h', 'i', 'l', 'd', 0,
    'C', 'u', 'l', 'l', 'F', 'r', 'o', 'n', 't', 0,
    'f', 'i', 'l', 't', 'e', 'r', 'i', 'n', 'g', 0,
    'F', 'l', 'o', 'a', 't', 'T', 'y', 'p', 'e', 0,
    'D', 'r', 'a', 'w', 'L', 'i', 'n', 'e', 's', 0,
    'i', 'n', 'd', 'e', 'x', 'D', 'a', 't', 'a', 0,
    'i', 'n', 'd', 'e', 'x', 'T', 'y', 'p', 'e', 0,
    'G', 'L', '_', 'P', 'O', 'I', 'N', 'T', 'S', 0,
    'Q', 'S', 'G', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'c', 'l', 'e', 'a', 'r', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'f', 'i', 'l', 'l', 'C', 'o', 'l', 'o', 'r', 0,
    'd', 'r', 'o', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'a', 'p', 'T', 'o', 'I', 't', 'e', 'm', 0,
    's', 'e', 't', 'S', 'm', 'o', 'o', 't', 'h', 0,
    'b', 'o', 'o', 'l', 'V', 'a', 'l', 'u', 'e', 0,
    'r', 'e', 'a', 'l', 'V', 'a', 'l', 'u', 'e', 0,
    'i', 'm', 'a', 'g', 'e', 'T', 'y', 'p', 'e', 0,
    'h', 'i', 'd', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'h', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'M', 'a', 't', 'r', 'i', 'x', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'd', 0,
    't', 'u', 'p', 'l', 'e', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'M', 'i', 'p', 'm', 'a', 'p', 0,
    'i', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'l', 'i', 'n', 'e', 'W', 'i', 'd', 't', 'h', 0,
    'i', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 'n', 'd', 'E', 'v', 'e', 'n', 't', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'c', 'l', 'i', 'p', 'L', 'i', 's', 't', 0,
    'M', 'e', 't', 'a', 'l', 'R', 'h', 'i', 0,
    'S', 'o', 'f', 't', 'w', 'a', 'r', 'e', 0,
    'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'C', 'u', 'l', 'l', 'B', 'a', 'c', 'k', 0,
    'C', 'u', 'l', 'l', 'N', 'o', 'n', 'e', 0,
    'B', 'l', 'e', 'n', 'd', 'i', 'n', 'g', 0,
    'D', 'i', 'r', 't', 'y', 'A', 'l', 'l', 0,
    'G', 'L', '_', 'L', 'I', 'N', 'E', 'S', 0,
    'G', 'L', '_', 'F', 'L', 'O', 'A', 'T', 0,
    's', 'e', 't', 'F', 'o', 'c', 'u', 's', 0,
    'h', 'a', 's', 'F', 'o', 'c', 'u', 's', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'e', 0,
    's', 'e', 't', 'S', 't', 'a', 't', 'e', 0,
    'T', 'o', 'p', 'R', 'i', 'g', 'h', 't', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'a', 'l', 'l', 'o', 'c', 'a', 't', 'e', 0,
    'c', 'l', 'i', 'p', 'R', 'e', 'c', 't', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'F', 'l', 'a', 'g', 's', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 0,
    'f', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    'N', 'u', 'l', 'l', 'R', 'h', 'i', 0,
    'Q', 'S', 'G', 'N', 'o', 'd', 'e', 0,
    'c', 'o', 'm', 'p', 'i', 'l', 'e', 0,
    'G', 'L', '_', 'B', 'Y', 'T', 'E', 0,
    'N', 'o', 'S', 't', 'a', 'g', 'e', 0,
    'c', 'l', 'o', 's', 'i', 'n', 'g', 0,
    'f', 'o', 'r', 'w', 'a', 'r', 'd', 0,
    'c', 'h', 'i', 'l', 'd', 'A', 't', 0,
    's', 'e', 't', 'C', 'l', 'i', 'p', 0,
    'T', 'o', 'p', 'L', 'e', 'f', 't', 0,
    'L', 'o', 'a', 'd', 'i', 'n', 'g', 0,
    'o', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'N', 'e', 'a', 'r', 'e', 's', 't', 0,
    's', 'e', 't', 'F', 'l', 'a', 'g', 0,
    'q', 'u', 'e', 'r', 'i', 'e', 's', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 0,
    's', 'e', 't', 'R', 'e', 'c', 't', 0,
    'p', 'r', 'o', 'g', 'r', 'a', 'm', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 0,
    'c', 'o', 'm', 'p', 'a', 'r', 'e', 0,
    '_', '_', 'l', 'e', 'n', '_', '_', 0,
    'o', 'p', 't', 'i', 'o', 'n', 's', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    'G', 'L', '_', 'I', 'N', 'T', 0,
    'p', 'o', 'l', 'i', 's', 'h', 0,
    's', 'm', 'o', 'o', 't', 'h', 0,
    'B', 'o', 't', 't', 'o', 'm', 0,
    'C', 'e', 'n', 't', 'e', 'r', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 0,
    'e', 'r', 'r', 'o', 'r', 's', 0,
    'l', 'a', 'y', 'o', 'u', 't', 0,
    'O', 'p', 'e', 'n', 'V', 'G', 0,
    'O', 'p', 'e', 'n', 'G', 'L', 0,
    's', 't', 'r', 'i', 'd', 'e', 0,
    'm', 'i', 'p', 'm', 'a', 'p', 0,
    'e', 'n', 'g', 'i', 'n', 'e', 0,
    'm', 'a', 't', 'r', 'i', 'x', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 0,
    'u', 'p', 'd', 'a', 't', 'e', 0,
    'c', 'u', 'r', 's', 'o', 'r', 0,
    'c', 'a', 'n', 'c', 'e', 'l', 0,
    'c', 'r', 'e', 'a', 't', 'e', 0,
    'h', 'e', 'i', 'g', 'h', 't', 0,
    'o', 'f', 'f', 's', 'e', 't', 0,
    'L', 'i', 'n', 'e', 'a', 'r', 0,
    's', 't', 'a', 't', 'u', 's', 0,
    'f', 'o', 'r', 'm', 'a', 't', 0,
    'o', 'b', 'j', 'e', 'c', 't', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'f', 'o', 'r', 'c', 'e', 0,
    'f', 'b', 'o', 'I', 'd', 0,
    'r', 'e', 'a', 'd', 'y', 0,
    'R', 'e', 'a', 'd', 'y', 0,
    'p', 'a', 'i', 'n', 't', 0,
    's', 'c', 'a', 'l', 'e', 0,
    'c', 'o', 'l', 'o', 'r', 0,
    'i', 'm', 'a', 'g', 'e', 0,
    'N', 'o', 'n', 'e', '_', 0,
    'w', 'i', 'd', 't', 'h', 0,
    'c', 'o', 'u', 'n', 't', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'e', 'v', 'e', 'n', 't', 0,
    's', 't', 'a', 't', 'e', 0,
    'H', 'L', 'S', 'L', 0,
    'G', 'L', 'S', 'L', 0,
    'Z', 'e', 'r', 'o', 0,
    'g', 'r', 'a', 'b', 0,
    's', 'e', 't', 'Z', 0,
    'b', 'i', 'n', 'd', 0,
    'i', 't', 'e', 'm', 0,
    'r', 'e', 'c', 't', 0,
    'c', 'l', 'i', 'p', 0,
    's', 'y', 'n', 'c', 0,
    's', 'e', 't', 'Y', 0,
    's', 'e', 't', 'X', 0,
    'N', 'u', 'l', 'l', 0,
    's', 'i', 'z', 'e', 0,
    't', 'y', 'p', 'e', 0,
    'O', 'n', 'e', 0,
    'T', 'o', 'p', 0,
    'u', 'r', 'l', 0,
    't', 'x', 0,
    'B', 0,
    'R', 0,
    'A', 0,
    'z', 0,
};
#line 203 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
// Release any attribute names to the heap.
static void qtquick_anc_release(char **attr_names)
{
    if (attr_names)
    {
        for (int i = 0; attr_names[i]; ++i)
            delete[] attr_names[i];

        delete[] attr_names;
    }
}


// The destructor for the attribute names PyCapsule.
static void qtquick_anc_destructor(PyObject *cap)
{
    qtquick_anc_release(
            reinterpret_cast<char **>(PyCapsule_GetPointer(cap, NULL)));
}


// Get the attribute names or 0 if there was an error.
static char **qtquick_anc_get_attr_names(sipSimpleWrapper *pySelf, PyObject *method, PyObject *attr_names_obj)
{
    // Dispose of any existing names.
    Py_XDECREF(sipGetUserObject(pySelf));
    sipSetUserObject(pySelf, NULL);

    // Convert the new names.
    if (!PyList_Check(attr_names_obj))
    {
        sipBadCatcherResult(method);
        return 0;
    }

    char **names = new char *[PyList_Size(attr_names_obj) + 1];

    for (Py_ssize_t i = 0; i < PyList_Size(attr_names_obj); ++i)
    {
        char *name;
        PyObject *el = PyList_GetItem(attr_names_obj, i);

#if PY_MAJOR_VERSION >= 3
        PyObject *name_obj = PyUnicode_AsASCIIString(el);

        name = (name_obj ? PyBytes_AsString(name_obj) : 0);
#else
        name = PyString_AsString(el);
#endif

        if (!name)
        {
            names[i] = 0;
            qtquick_anc_release(names);

            sipBadCatcherResult(method);
            return 0;
        }

        char *name_copy = new char[strlen(name) + 1];
        strcpy(name_copy, name);
        names[i] = name_copy;

#if PY_MAJOR_VERSION >= 3
        Py_DECREF(name_obj);
#endif
    }

    names[PyList_Size(attr_names_obj)] = 0;

    sipSetUserObject(pySelf, PyCapsule_New(names, NULL, qtquick_anc_destructor));

    if (!sipGetUserObject(pySelf))
    {
        qtquick_anc_release(names);
        return 0;
    }

    return names;
}
#line 1187 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"

 ::QSGTexture* sipVH_QtQuick_86(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGTexture* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QSGTexture, &sipRes);

    return sipRes;
}

void* sipVH_QtQuick_85(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const char*a0)
{
    void* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "A", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "V", &sipRes);

    return sipRes;
}

const  ::QRegion* sipVH_QtQuick_84(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QRegion* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QRegion, &sipRes);

    return sipRes;
}

 ::QRect sipVH_QtQuick_83(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QRect sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRect, &sipRes);

    return sipRes;
}

const  ::QMatrix4x4* sipVH_QtQuick_82(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QMatrix4x4* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QMatrix4x4, &sipRes);

    return sipRes;
}

 ::QSGRenderNode::RenderingFlags sipVH_QtQuick_81(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGRenderNode::RenderingFlags sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSGRenderNode_RenderingFlags, &sipRes);

    return sipRes;
}

void sipVH_QtQuick_80(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QSGRenderNode::RenderState*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", const_cast< ::QSGRenderNode::RenderState *>(a0), sipType_QSGRenderNode_RenderState, SIP_NULLPTR);
}

 ::QSGRenderNode::StateFlags sipVH_QtQuick_79(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGRenderNode::StateFlags sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSGRenderNode_StateFlags, &sipRes);

    return sipRes;
}

 ::QSGRendererInterface::ShaderSourceTypes sipVH_QtQuick_78(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGRendererInterface::ShaderSourceTypes sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSGRendererInterface_ShaderSourceTypes, &sipRes);

    return sipRes;
}

 ::QSGRendererInterface::ShaderCompilationTypes sipVH_QtQuick_77(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGRendererInterface::ShaderCompilationTypes sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSGRendererInterface_ShaderCompilationTypes, &sipRes);

    return sipRes;
}

 ::QSGRendererInterface::ShaderType sipVH_QtQuick_76(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGRendererInterface::ShaderType sipRes =  ::QSGRendererInterface::UnknownShadingLanguage;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QSGRendererInterface_ShaderType, &sipRes);

    return sipRes;
}

void* sipVH_QtQuick_75(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QQuickWindow*a0,const char*a1)
{
    void* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DA", a0, sipType_QQuickWindow, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "V", &sipRes);

    return sipRes;
}

void* sipVH_QtQuick_74(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QQuickWindow*a0, ::QSGRendererInterface::Resource a1)
{
    void* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DF", a0, sipType_QQuickWindow, SIP_NULLPTR, a1, sipType_QSGRendererInterface_Resource);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "V", &sipRes);

    return sipRes;
}

 ::QSGRendererInterface::GraphicsApi sipVH_QtQuick_73(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGRendererInterface::GraphicsApi sipRes =  ::QSGRendererInterface::Unknown;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QSGRendererInterface_GraphicsApi, &sipRes);

    return sipRes;
}

 ::QColor sipVH_QtQuick_72(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QColor sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QColor, &sipRes);

    return sipRes;
}

void sipVH_QtQuick_71(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QColor& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QColor(a0), sipType_QColor, SIP_NULLPTR);
}

bool sipVH_QtQuick_70(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QSGMaterialRhiShader::RenderState& a0, ::QSGMaterialRhiShader::GraphicsPipelineState*a1, ::QSGMaterial*a2, ::QSGMaterial*a3)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DDDD", &a0, sipType_QSGMaterialRhiShader_RenderState, SIP_NULLPTR, a1, sipType_QSGMaterialRhiShader_GraphicsPipelineState, SIP_NULLPTR, a2, sipType_QSGMaterial, SIP_NULLPTR, a3, sipType_QSGMaterial, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtQuick_69(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QSGMaterialRhiShader::RenderState& a0,int a1, ::QSGTexture**a2, ::QSGMaterial*a3, ::QSGMaterial*a4)
{
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DiDD", &a0, sipType_QSGMaterialRhiShader_RenderState, SIP_NULLPTR, a1, a3, sipType_QSGMaterial, SIP_NULLPTR, a4, sipType_QSGMaterial, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QSGTexture, a2);
}

bool sipVH_QtQuick_68(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QSGMaterialRhiShader::RenderState& a0, ::QSGMaterial*a1, ::QSGMaterial*a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DDD", &a0, sipType_QSGMaterialRhiShader_RenderState, SIP_NULLPTR, a1, sipType_QSGMaterial, SIP_NULLPTR, a2, sipType_QSGMaterial, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

const char* sipVH_QtQuick_67(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int sipResKey)
{
    char* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "AA", sipResKey, &sipRes);

    return sipRes;
}

const char* const* sipVH_QtQuick_66(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int)
{
    char* const* sipRes = 0;
    int sipIsErr = 0;

#line 114 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgmaterial.sip"
        PyObject *names = sipCallMethod(&sipIsErr, sipMethod, "");
        
        if (names)
        {
            sipRes = qtquick_anc_get_attr_names(sipPySelf, sipMethod, names);
            
            if (!sipRes)
                sipIsErr = 1;
            
            Py_DECREF(names);
        }
#line 1393 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"

    Py_DECREF(sipMethod);

    if (sipIsErr)
        sipCallErrorHandler(sipErrorHandler, sipPySelf, sipGILState);

    SIP_RELEASE_GIL(sipGILState)

    return sipRes;
}

void sipVH_QtQuick_65(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QSGMaterialShader::RenderState& a0, ::QSGMaterial*a1, ::QSGMaterial*a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NDD", new  ::QSGMaterialShader::RenderState(a0), sipType_QSGMaterialShader_RenderState, SIP_NULLPTR, a1, sipType_QSGMaterial, SIP_NULLPTR, a2, sipType_QSGMaterial, SIP_NULLPTR);
}

void sipVH_QtQuick_64(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "b", a0);
}

 ::QSGImageNode::TextureCoordinatesTransformMode sipVH_QtQuick_63(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGImageNode::TextureCoordinatesTransformMode sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSGImageNode_TextureCoordinatesTransformMode, &sipRes);

    return sipRes;
}

void sipVH_QtQuick_62(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QSGImageNode::TextureCoordinatesTransformMode a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QSGImageNode::TextureCoordinatesTransformMode(a0), sipType_QSGImageNode_TextureCoordinatesTransformMode, SIP_NULLPTR);
}

 ::QSGTexture::Filtering sipVH_QtQuick_61(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGTexture::Filtering sipRes =  ::QSGTexture::None;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QSGTexture_Filtering, &sipRes);

    return sipRes;
}

void sipVH_QtQuick_60(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QSGTexture::Filtering a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QSGTexture_Filtering);
}

 ::QSGTexture* sipVH_QtQuick_59(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGTexture* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QSGTexture, &sipRes);

    return sipRes;
}

void sipVH_QtQuick_58(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QSGTexture*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QSGTexture, SIP_NULLPTR);
}

 ::QRectF sipVH_QtQuick_57(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QRectF sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QRectF, &sipRes);

    return sipRes;
}

void sipVH_QtQuick_56(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QRectF& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QRectF(a0), sipType_QRectF, SIP_NULLPTR);
}

int sipVH_QtQuick_55(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QSGMaterial*a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", const_cast< ::QSGMaterial *>(a0), sipType_QSGMaterial, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

 ::QSGMaterialShader* sipVH_QtQuick_54(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGMaterialShader* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QSGMaterialShader, &sipRes);

    return sipRes;
}

 ::QSGMaterialType* sipVH_QtQuick_53(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGMaterialType* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QSGMaterialType, &sipRes);

    return sipRes;
}

void sipVH_QtQuick_52(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::GLuint a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "u", a0);
}

 ::QSurface::SurfaceType sipVH_QtQuick_51(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSurface::SurfaceType sipRes =  ::QSurface::RasterSurface;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QSurface_SurfaceType, &sipRes);

    return sipRes;
}

 ::QSurfaceFormat sipVH_QtQuick_50(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSurfaceFormat sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSurfaceFormat, &sipRes);

    return sipRes;
}

 ::QObject* sipVH_QtQuick_49(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QObject, &sipRes);

    return sipRes;
}

void sipVH_QtQuick_48(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QExposeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QExposeEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_47(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QResizeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QResizeEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_46(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMoveEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_45(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QShowEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QShowEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_44(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QHideEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QHideEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_43(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QTabletEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTabletEvent, SIP_NULLPTR);
}

 ::QWindow* sipVH_QtQuick_42(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QPoint*a0)
{
     ::QWindow* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QPoint, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QWindow, &sipRes);

    return sipRes;
}

void sipVH_QtQuick_41(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QPainter*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPainter, SIP_NULLPTR);
}

 ::QQuickImageResponse* sipVH_QtQuick_40(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QString& a0,const  ::QSize& a1)
{
     ::QQuickImageResponse* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new  ::QString(a0), sipType_QString, SIP_NULLPTR, new  ::QSize(a1), sipType_QSize, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QQuickImageResponse, &sipRes);

    return sipRes;
}

 ::QString sipVH_QtQuick_39(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

 ::QQuickTextureFactory* sipVH_QtQuick_38(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QQuickTextureFactory* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QQuickTextureFactory, &sipRes);

    return sipRes;
}

 ::QQuickTextureFactory* sipVH_QtQuick_37(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QString& a0, ::QSize*a1,const  ::QSize& a2)
{
     ::QQuickTextureFactory* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new  ::QString(a0), sipType_QString, SIP_NULLPTR, new  ::QSize(a2), sipType_QSize, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(H2H4)", sipType_QQuickTextureFactory, &sipRes, sipType_QSize, a1);

    return sipRes;
}

 ::QPixmap sipVH_QtQuick_36(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QString& a0, ::QSize*a1,const  ::QSize& a2)
{
     ::QPixmap sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new  ::QString(a0), sipType_QString, SIP_NULLPTR, new  ::QSize(a2), sipType_QSize, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(H5H4)", sipType_QPixmap, &sipRes, sipType_QSize, a1);

    return sipRes;
}

 ::QImage sipVH_QtQuick_35(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QString& a0, ::QSize*a1,const  ::QSize& a2)
{
     ::QImage sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new  ::QString(a0), sipType_QString, SIP_NULLPTR, new  ::QSize(a2), sipType_QSize, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(H5H4)", sipType_QImage, &sipRes, sipType_QSize, a1);

    return sipRes;
}

 ::QQmlImageProviderBase::ImageType sipVH_QtQuick_34(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QQmlImageProviderBase::ImageType sipRes =  ::QQmlImageProviderBase::Image;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QQmlImageProviderBase_ImageType, &sipRes);

    return sipRes;
}

 ::QQmlImageProviderBase::Flags sipVH_QtQuick_33(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QQmlImageProviderBase::Flags sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QQmlImageProviderBase_Flags, &sipRes);

    return sipRes;
}

 ::QImage sipVH_QtQuick_32(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QImage sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QImage, &sipRes);

    return sipRes;
}

int sipVH_QtQuick_31(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

 ::QSize sipVH_QtQuick_30(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

 ::QSGTexture* sipVH_QtQuick_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QQuickWindow*a0)
{
     ::QSGTexture* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QQuickWindow, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QSGTexture, &sipRes);

    return sipRes;
}

void sipVH_QtQuick_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QQuickFramebufferObject*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QQuickFramebufferObject, SIP_NULLPTR);
}

 ::QOpenGLFramebufferObject* sipVH_QtQuick_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QSize& a0)
{
     ::QOpenGLFramebufferObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QSize(a0), sipType_QSize, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QOpenGLFramebufferObject, &sipRes);

    return sipRes;
}

 ::QQuickFramebufferObject::Renderer* sipVH_QtQuick_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QQuickFramebufferObject::Renderer* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QQuickFramebufferObject_Renderer, &sipRes);

    return sipRes;
}

 ::QSGNode* sipVH_QtQuick_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QSGNode*a0, ::QQuickItem::UpdatePaintNodeData*a1)
{
     ::QSGNode* sipRes = 0;
    int sipIsErr = 0;

#line 233 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickitem.sip"
        PyObject *res;
        
        res = sipCallMethod(&sipIsErr, sipMethod, "DD",
                a0, sipType_QSGNode, NULL,
                a1, sipType_QQuickItem_UpdatePaintNodeData, NULL);
        
        if (res)
        {
            sipParseResult(&sipIsErr, sipMethod, res, "H0", sipType_QSGNode, &sipRes);
        
            if (!sipIsErr && sipRes && (sipRes->flags() & QSGNode::OwnedByParent))
                sipTransferTo(res, (PyObject *)sipPySelf);
        
            Py_DECREF(res);
        }
#line 1751 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"

    Py_DECREF(sipMethod);

    if (sipIsErr)
        sipCallErrorHandler(sipErrorHandler, sipPySelf, sipGILState);

    SIP_RELEASE_GIL(sipGILState)

    return sipRes;
}

void sipVH_QtQuick_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QRectF& a0,const  ::QRectF& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NN", new  ::QRectF(a0), sipType_QRectF, SIP_NULLPTR, new  ::QRectF(a1), sipType_QRectF, SIP_NULLPTR);
}

bool sipVH_QtQuick_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QQuickItem*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QQuickItem, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtQuick_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QDropEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDropEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QDragLeaveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragLeaveEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QDragMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragMoveEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QDragEnterEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragEnterEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QHoverEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QHoverEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QTouchEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTouchEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QWheelEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWheelEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QMouseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMouseEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QFocusEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QFocusEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QInputMethodEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QInputMethodEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QKeyEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QKeyEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QQuickItem::ItemChange a0,const  ::QQuickItem::ItemChangeData& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "FN", a0, sipType_QQuickItem_ItemChange, new  ::QQuickItem::ItemChangeData(a1), sipType_QQuickItem_ItemChangeData, SIP_NULLPTR);
}

 ::QSGTextureProvider* sipVH_QtQuick_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
     ::QSGTextureProvider* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QSGTextureProvider, &sipRes);

    return sipRes;
}

bool sipVH_QtQuick_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

 ::QVariant sipVH_QtQuick_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::Qt::InputMethodQuery a0)
{
     ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_Qt_InputMethodQuery);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtQuick_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QPointF& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new  ::QPointF(a0), sipType_QPointF, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtQuick_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

bool sipVH_QtQuick_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtQuick_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtQuick_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod,  ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtQuick_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const  ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new  ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QQuickWindow(void **);}
static const sipTypeDef *sipSubClass_QQuickWindow(void **sipCppRet)
{
     ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickwindow.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
    #if QT_VERSION >= 0x050400
        {sipName_QSGEngine, &sipType_QSGEngine, -1, 1},
    #else
        {0, 0, -1, 1},
    #endif
        {sipName_QQuickItem, &sipType_QQuickItem, 11, 2},
    #if QT_VERSION >= 0x050400
        {sipName_QQuickItemGrabResult, &sipType_QQuickItemGrabResult, -1, 3},
    #else
        {0, 0, -1, 3},
    #endif
        {sipName_QSGTexture, &sipType_QSGTexture, 13, 4},
    #if QT_VERSION >= 0x050100
        {sipName_QQuickTextDocument, &sipType_QQuickTextDocument, -1, 5},
    #else
        {0, 0, -1, 5},
    #endif
    #if QT_VERSION >= 0x050400
        {sipName_QSGAbstractRenderer, &sipType_QSGAbstractRenderer, -1, 6},
    #else
        {0, 0, -1, 6},
    #endif
    #if QT_VERSION >= 0x050600
        {sipName_QQuickImageResponse, &sipType_QQuickImageResponse, -1, 7},
    #else
        {0, 0, -1, 7},
    #endif
        {sipName_QQuickTextureFactory, &sipType_QQuickTextureFactory, -1, 8},
    #if QT_VERSION >= 0x050400
        {sipName_QQuickRenderControl, &sipType_QQuickRenderControl, -1, 9},
    #else
        {0, 0, -1, 9},
    #endif
        {sipName_QSGTextureProvider, &sipType_QSGTextureProvider, -1, 10},
        {sipName_QQuickWindow, &sipType_QQuickWindow, 14, -1},
    #if QT_VERSION >= 0x050200
        {sipName_QQuickFramebufferObject, &sipType_QQuickFramebufferObject, -1, 12},
    #else
        {0, 0, -1, 12},
    #endif
        {sipName_QQuickPaintedItem, &sipType_QQuickPaintedItem, -1, -1},
        {sipName_QSGDynamicTexture, &sipType_QSGDynamicTexture, -1, -1},
        {sipName_QQuickView, &sipType_QQuickView, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 1999 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"

    return sipType;
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QSGNode(void **);}
static const sipTypeDef *sipSubClass_QSGNode(void **sipCppRet)
{
     ::QSGNode *sipCpp = reinterpret_cast< ::QSGNode *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 126 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qsgnode.sip"
    switch (sipCpp->type())
    {
    case QSGNode::BasicNodeType:
        sipType = sipType_QSGBasicGeometryNode;
        break;
    
    case QSGNode::GeometryNodeType:
        sipType = sipType_QSGGeometryNode;
        break;
    
    case QSGNode::TransformNodeType:
        sipType = sipType_QSGClipNode;
        break;
    
    case QSGNode::ClipNodeType:
        sipType = sipType_QSGTransformNode;
        break;
    
    case QSGNode::OpacityNodeType:
        sipType = sipType_QSGOpacityNode;
        break;
    
    default:
        sipType = 0;
    }
#line 2038 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"

    return sipType;
}


extern "C" {static PyObject *slot_QSGSimpleTextureNode_TextureCoordinatesTransformFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGSimpleTextureNode_TextureCoordinatesTransformFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGSimpleTextureNode::TextureCoordinatesTransformFlag a0;
         ::QSGSimpleTextureNode::TextureCoordinatesTransformMode* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGSimpleTextureNode_TextureCoordinatesTransformFlag, &a0, sipType_QSGSimpleTextureNode_TextureCoordinatesTransformMode, &a1, &a1State))
        {
             ::QSGSimpleTextureNode::TextureCoordinatesTransformMode*sipRes;

            sipRes = new  ::QSGSimpleTextureNode::TextureCoordinatesTransformMode((a0 | *a1));
            sipReleaseType(a1,sipType_QSGSimpleTextureNode_TextureCoordinatesTransformMode,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGSimpleTextureNode_TextureCoordinatesTransformMode,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGSimpleTextureNode_TextureCoordinatesTransformFlag[] = {
    {(void *)slot_QSGSimpleTextureNode_TextureCoordinatesTransformFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSGRenderNode_RenderingFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGRenderNode_RenderingFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGRenderNode::RenderingFlag a0;
         ::QSGRenderNode::RenderingFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGRenderNode_RenderingFlag, &a0, sipType_QSGRenderNode_RenderingFlags, &a1, &a1State))
        {
             ::QSGRenderNode::RenderingFlags*sipRes;

            sipRes = new  ::QSGRenderNode::RenderingFlags((a0 | *a1));
            sipReleaseType(a1,sipType_QSGRenderNode_RenderingFlags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGRenderNode_RenderingFlags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGRenderNode_RenderingFlag[] = {
    {(void *)slot_QSGRenderNode_RenderingFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSGRenderNode_StateFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGRenderNode_StateFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGRenderNode::StateFlag a0;
         ::QSGRenderNode::StateFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGRenderNode_StateFlag, &a0, sipType_QSGRenderNode_StateFlags, &a1, &a1State))
        {
             ::QSGRenderNode::StateFlags*sipRes;

            sipRes = new  ::QSGRenderNode::StateFlags((a0 | *a1));
            sipReleaseType(a1,sipType_QSGRenderNode_StateFlags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGRenderNode_StateFlags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGRenderNode_StateFlag[] = {
    {(void *)slot_QSGRenderNode_StateFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSGRendererInterface_ShaderSourceType___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGRendererInterface_ShaderSourceType___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGRendererInterface::ShaderSourceType a0;
         ::QSGRendererInterface::ShaderSourceTypes* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGRendererInterface_ShaderSourceType, &a0, sipType_QSGRendererInterface_ShaderSourceTypes, &a1, &a1State))
        {
             ::QSGRendererInterface::ShaderSourceTypes*sipRes;

            sipRes = new  ::QSGRendererInterface::ShaderSourceTypes((a0 | *a1));
            sipReleaseType(a1,sipType_QSGRendererInterface_ShaderSourceTypes,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGRendererInterface_ShaderSourceTypes,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGRendererInterface_ShaderSourceType[] = {
    {(void *)slot_QSGRendererInterface_ShaderSourceType___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSGRendererInterface_ShaderCompilationType___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGRendererInterface_ShaderCompilationType___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGRendererInterface::ShaderCompilationType a0;
         ::QSGRendererInterface::ShaderCompilationTypes* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGRendererInterface_ShaderCompilationType, &a0, sipType_QSGRendererInterface_ShaderCompilationTypes, &a1, &a1State))
        {
             ::QSGRendererInterface::ShaderCompilationTypes*sipRes;

            sipRes = new  ::QSGRendererInterface::ShaderCompilationTypes((a0 | *a1));
            sipReleaseType(a1,sipType_QSGRendererInterface_ShaderCompilationTypes,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGRendererInterface_ShaderCompilationTypes,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGRendererInterface_ShaderCompilationType[] = {
    {(void *)slot_QSGRendererInterface_ShaderCompilationType___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSGNode_DirtyStateBit___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGNode_DirtyStateBit___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGNode::DirtyStateBit a0;
         ::QSGNode::DirtyState* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGNode_DirtyStateBit, &a0, sipType_QSGNode_DirtyState, &a1, &a1State))
        {
             ::QSGNode::DirtyState*sipRes;

            sipRes = new  ::QSGNode::DirtyState((a0 | *a1));
            sipReleaseType(a1,sipType_QSGNode_DirtyState,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGNode_DirtyState,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGNode_DirtyStateBit[] = {
    {(void *)slot_QSGNode_DirtyStateBit___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSGNode_Flag___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGNode_Flag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGNode::Flag a0;
         ::QSGNode::Flags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGNode_Flag, &a0, sipType_QSGNode_Flags, &a1, &a1State))
        {
             ::QSGNode::Flags*sipRes;

            sipRes = new  ::QSGNode::Flags((a0 | *a1));
            sipReleaseType(a1,sipType_QSGNode_Flags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGNode_Flags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGNode_Flag[] = {
    {(void *)slot_QSGNode_Flag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSGMaterialRhiShader_Flag___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGMaterialRhiShader_Flag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGMaterialRhiShader::Flag a0;
         ::QSGMaterialRhiShader::Flags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGMaterialRhiShader_Flag, &a0, sipType_QSGMaterialRhiShader_Flags, &a1, &a1State))
        {
             ::QSGMaterialRhiShader::Flags*sipRes;

            sipRes = new  ::QSGMaterialRhiShader::Flags((a0 | *a1));
            sipReleaseType(a1,sipType_QSGMaterialRhiShader_Flags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGMaterialRhiShader_Flags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGMaterialRhiShader_Flag[] = {
    {(void *)slot_QSGMaterialRhiShader_Flag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSGMaterialRhiShader_GraphicsPipelineState_ColorMaskComponent___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGMaterialRhiShader_GraphicsPipelineState_ColorMaskComponent___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGMaterialRhiShader::GraphicsPipelineState::ColorMaskComponent a0;
         ::QSGMaterialRhiShader::GraphicsPipelineState::ColorMask* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGMaterialRhiShader_GraphicsPipelineState_ColorMaskComponent, &a0, sipType_QSGMaterialRhiShader_GraphicsPipelineState_ColorMask, &a1, &a1State))
        {
             ::QSGMaterialRhiShader::GraphicsPipelineState::ColorMask*sipRes;

            sipRes = new  ::QSGMaterialRhiShader::GraphicsPipelineState::ColorMask((a0 | *a1));
            sipReleaseType(a1,sipType_QSGMaterialRhiShader_GraphicsPipelineState_ColorMask,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGMaterialRhiShader_GraphicsPipelineState_ColorMask,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGMaterialRhiShader_GraphicsPipelineState_ColorMaskComponent[] = {
    {(void *)slot_QSGMaterialRhiShader_GraphicsPipelineState_ColorMaskComponent___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSGMaterial_Flag___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGMaterial_Flag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGMaterial::Flag a0;
         ::QSGMaterial::Flags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGMaterial_Flag, &a0, sipType_QSGMaterial_Flags, &a1, &a1State))
        {
             ::QSGMaterial::Flags*sipRes;

            sipRes = new  ::QSGMaterial::Flags((a0 | *a1));
            sipReleaseType(a1,sipType_QSGMaterial_Flags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGMaterial_Flags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGMaterial_Flag[] = {
    {(void *)slot_QSGMaterial_Flag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSGMaterialShader_RenderState_DirtyState___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGMaterialShader_RenderState_DirtyState___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGMaterialShader::RenderState::DirtyState a0;
         ::QSGMaterialShader::RenderState::DirtyStates* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGMaterialShader_RenderState_DirtyState, &a0, sipType_QSGMaterialShader_RenderState_DirtyStates, &a1, &a1State))
        {
             ::QSGMaterialShader::RenderState::DirtyStates*sipRes;

            sipRes = new  ::QSGMaterialShader::RenderState::DirtyStates((a0 | *a1));
            sipReleaseType(a1,sipType_QSGMaterialShader_RenderState_DirtyStates,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGMaterialShader_RenderState_DirtyStates,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGMaterialShader_RenderState_DirtyState[] = {
    {(void *)slot_QSGMaterialShader_RenderState_DirtyState___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSGImageNode_TextureCoordinatesTransformFlag___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGImageNode_TextureCoordinatesTransformFlag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGImageNode::TextureCoordinatesTransformFlag a0;
         ::QSGImageNode::TextureCoordinatesTransformMode* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGImageNode_TextureCoordinatesTransformFlag, &a0, sipType_QSGImageNode_TextureCoordinatesTransformMode, &a1, &a1State))
        {
             ::QSGImageNode::TextureCoordinatesTransformMode*sipRes;

            sipRes = new  ::QSGImageNode::TextureCoordinatesTransformMode((a0 | *a1));
            sipReleaseType(a1,sipType_QSGImageNode_TextureCoordinatesTransformMode,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGImageNode_TextureCoordinatesTransformMode,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGImageNode_TextureCoordinatesTransformFlag[] = {
    {(void *)slot_QSGImageNode_TextureCoordinatesTransformFlag___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QSGAbstractRenderer_ClearModeBit___or__(PyObject *,PyObject *);}
static PyObject *slot_QSGAbstractRenderer_ClearModeBit___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSGAbstractRenderer::ClearModeBit a0;
         ::QSGAbstractRenderer::ClearMode* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSGAbstractRenderer_ClearModeBit, &a0, sipType_QSGAbstractRenderer_ClearMode, &a1, &a1State))
        {
             ::QSGAbstractRenderer::ClearMode*sipRes;

            sipRes = new  ::QSGAbstractRenderer::ClearMode((a0 | *a1));
            sipReleaseType(a1,sipType_QSGAbstractRenderer_ClearMode,a1State);

            return sipConvertFromNewType(sipRes,sipType_QSGAbstractRenderer_ClearMode,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSGAbstractRenderer_ClearModeBit[] = {
    {(void *)slot_QSGAbstractRenderer_ClearModeBit___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QQuickPaintedItem_PerformanceHint___or__(PyObject *,PyObject *);}
static PyObject *slot_QQuickPaintedItem_PerformanceHint___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QQuickPaintedItem::PerformanceHint a0;
         ::QQuickPaintedItem::PerformanceHints* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QQuickPaintedItem_PerformanceHint, &a0, sipType_QQuickPaintedItem_PerformanceHints, &a1, &a1State))
        {
             ::QQuickPaintedItem::PerformanceHints*sipRes;

            sipRes = new  ::QQuickPaintedItem::PerformanceHints((a0 | *a1));
            sipReleaseType(a1,sipType_QQuickPaintedItem_PerformanceHints,a1State);

            return sipConvertFromNewType(sipRes,sipType_QQuickPaintedItem_PerformanceHints,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QQuickPaintedItem_PerformanceHint[] = {
    {(void *)slot_QQuickPaintedItem_PerformanceHint___or__, or_slot},
    {0, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QQuickItem_Flag___or__(PyObject *,PyObject *);}
static PyObject *slot_QQuickItem_Flag___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QQuickItem::Flag a0;
         ::QQuickItem::Flags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QQuickItem_Flag, &a0, sipType_QQuickItem_Flags, &a1, &a1State))
        {
             ::QQuickItem::Flags*sipRes;

            sipRes = new  ::QQuickItem::Flags((a0 | *a1));
            sipReleaseType(a1,sipType_QQuickItem_Flags,a1State);

            return sipConvertFromNewType(sipRes,sipType_QQuickItem_Flags,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QQuickItem_Flag[] = {
    {(void *)slot_QQuickItem_Flag___or__, or_slot},
    {0, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGTexture__AnisotropyLevel, {0}, 0}, sipNameNr_AnisotropyLevel, 102, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGTexture__Filtering, {0}, 0}, sipNameNr_Filtering, 102, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGTexture__WrapMode, {0}, 0}, sipNameNr_WrapMode, 102, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGSimpleTextureNode__TextureCoordinatesTransformFlag, {0}, 0}, sipNameNr_TextureCoordinatesTransformFlag, 99, slots_QSGSimpleTextureNode_TextureCoordinatesTransformFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGRenderNode__RenderingFlag, {0}, 0}, sipNameNr_RenderingFlag, 84, slots_QSGRenderNode_RenderingFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGRenderNode__StateFlag, {0}, 0}, sipNameNr_StateFlag, 84, slots_QSGRenderNode_StateFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGRendererInterface__ShaderSourceType, {0}, 0}, sipNameNr_ShaderSourceType, 90, slots_QSGRendererInterface_ShaderSourceType},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGRendererInterface__ShaderCompilationType, {0}, 0}, sipNameNr_ShaderCompilationType, 90, slots_QSGRendererInterface_ShaderCompilationType},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGRendererInterface__ShaderType, {0}, 0}, sipNameNr_ShaderType, 90, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGRendererInterface__Resource, {0}, 0}, sipNameNr_Resource, 90, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGRendererInterface__GraphicsApi, {0}, 0}, sipNameNr_GraphicsApi, 90, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGNode__DirtyStateBit, {0}, 0}, sipNameNr_DirtyStateBit, 75, slots_QSGNode_DirtyStateBit},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGNode__Flag, {0}, 0}, sipNameNr_Flag, 75, slots_QSGNode_Flag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGNode__NodeType, {0}, 0}, sipNameNr_NodeType, 75, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGMaterialRhiShader__Flag, {0}, 0}, sipNameNr_Flag, 61, slots_QSGMaterialRhiShader_Flag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGMaterialRhiShader__GraphicsPipelineState__CullMode, {0}, 0}, sipNameNr_CullMode, 64, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGMaterialRhiShader__GraphicsPipelineState__ColorMaskComponent, {0}, 0}, sipNameNr_ColorMaskComponent, 64, slots_QSGMaterialRhiShader_GraphicsPipelineState_ColorMaskComponent},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGMaterialRhiShader__GraphicsPipelineState__BlendFactor, {0}, 0}, sipNameNr_BlendFactor, 64, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGMaterial__Flag, {0}, 0}, sipNameNr_Flag, 58, slots_QSGMaterial_Flag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGMaterialShader__RenderState__DirtyState, {0}, 0}, sipNameNr_DirtyState, 71, slots_QSGMaterialShader_RenderState_DirtyState},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGImageNode__TextureCoordinatesTransformFlag, {0}, 0}, sipNameNr_TextureCoordinatesTransformFlag, 55, slots_QSGImageNode_TextureCoordinatesTransformFlag},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGGeometry__Type, {0}, 0}, sipNameNr_Type, 44, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGGeometry__DrawingMode, {0}, 0}, sipNameNr_DrawingMode, 44, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGGeometry__AttributeType, {0}, 0}, sipNameNr_AttributeType, 44, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGGeometry__DataPattern, {0}, 0}, sipNameNr_DataPattern, 44, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGEngine__CreateTextureOption, {0}, 0}, sipNameNr_CreateTextureOption, 40, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGAbstractRenderer__MatrixTransformFlag, {0}, 0}, sipNameNr_MatrixTransformFlag, 32, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QSGAbstractRenderer__ClearModeBit, {0}, 0}, sipNameNr_ClearModeBit, 32, slots_QSGAbstractRenderer_ClearModeBit},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QQuickWindow__NativeObjectType, {0}, 0}, sipNameNr_NativeObjectType, 25, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QQuickWindow__TextRenderType, {0}, 0}, sipNameNr_TextRenderType, 25, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QQuickWindow__RenderStage, {0}, 0}, sipNameNr_RenderStage, 25, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QQuickWindow__SceneGraphError, {0}, 0}, sipNameNr_SceneGraphError, 25, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QQuickWindow__CreateTextureOption, {0}, 0}, sipNameNr_CreateTextureOption, 25, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QQuickView__Status, {0}, 0}, sipNameNr_Status, 22, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QQuickView__ResizeMode, {0}, 0}, sipNameNr_ResizeMode, 22, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QQuickPaintedItem__PerformanceHint, {0}, 0}, sipNameNr_PerformanceHint, 15, slots_QQuickPaintedItem_PerformanceHint},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QQuickPaintedItem__RenderTarget, {0}, 0}, sipNameNr_RenderTarget, 15, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QQuickItem__TransformOrigin, {0}, 0}, sipNameNr_TransformOrigin, 7, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QQuickItem__ItemChange, {0}, 0}, sipNameNr_ItemChange, 7, SIP_NULLPTR},
    {{-1, 0, 0, SIP_TYPE_ENUM, sipNameNr_QQuickItem__Flag, {0}, 0}, sipNameNr_Flag, 7, slots_QQuickItem_Flag},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtQuick[] = {
    &sipTypeDef_QtQuick_QList_0101QQuickItem.mtd_base,
    &sipTypeDef_QtQuick_QQuickAsyncImageProvider.ctd_base,
    &sipTypeDef_QtQuick_QQuickCloseEvent.ctd_base,
    &sipTypeDef_QtQuick_QQuickFramebufferObject.ctd_base,
    &sipTypeDef_QtQuick_QQuickFramebufferObject_Renderer.ctd_base,
    &sipTypeDef_QtQuick_QQuickImageProvider.ctd_base,
    &sipTypeDef_QtQuick_QQuickImageResponse.ctd_base,
    &sipTypeDef_QtQuick_QQuickItem.ctd_base,
    &enumTypes[39].etd_base,
    &sipTypeDef_QtQuick_QQuickItem_Flags.ctd_base,
    &enumTypes[38].etd_base,
    &sipTypeDef_QtQuick_QQuickItem_ItemChangeData.ctd_base,
    &enumTypes[37].etd_base,
    &sipTypeDef_QtQuick_QQuickItem_UpdatePaintNodeData.ctd_base,
    &sipTypeDef_QtQuick_QQuickItemGrabResult.ctd_base,
    &sipTypeDef_QtQuick_QQuickPaintedItem.ctd_base,
    &enumTypes[35].etd_base,
    &sipTypeDef_QtQuick_QQuickPaintedItem_PerformanceHints.ctd_base,
    &enumTypes[36].etd_base,
    &sipTypeDef_QtQuick_QQuickRenderControl.ctd_base,
    &sipTypeDef_QtQuick_QQuickTextDocument.ctd_base,
    &sipTypeDef_QtQuick_QQuickTextureFactory.ctd_base,
    &sipTypeDef_QtQuick_QQuickView.ctd_base,
    &enumTypes[34].etd_base,
    &enumTypes[33].etd_base,
    &sipTypeDef_QtQuick_QQuickWindow.ctd_base,
    &enumTypes[32].etd_base,
    &sipTypeDef_QtQuick_QQuickWindow_CreateTextureOptions.ctd_base,
    &enumTypes[28].etd_base,
    &enumTypes[30].etd_base,
    &enumTypes[31].etd_base,
    &enumTypes[29].etd_base,
    &sipTypeDef_QtQuick_QSGAbstractRenderer.ctd_base,
    &sipTypeDef_QtQuick_QSGAbstractRenderer_ClearMode.ctd_base,
    &enumTypes[27].etd_base,
    &enumTypes[26].etd_base,
    &sipTypeDef_QtQuick_QSGAbstractRenderer_MatrixTransformFlags.ctd_base,
    &sipTypeDef_QtQuick_QSGBasicGeometryNode.ctd_base,
    &sipTypeDef_QtQuick_QSGClipNode.ctd_base,
    &sipTypeDef_QtQuick_QSGDynamicTexture.ctd_base,
    &sipTypeDef_QtQuick_QSGEngine.ctd_base,
    &enumTypes[25].etd_base,
    &sipTypeDef_QtQuick_QSGEngine_CreateTextureOptions.ctd_base,
    &sipTypeDef_QtQuick_QSGFlatColorMaterial.ctd_base,
    &sipTypeDef_QtQuick_QSGGeometry.ctd_base,
    &sipTypeDef_QtQuick_QSGGeometry_Attribute.ctd_base,
    &sipTypeDef_QtQuick_QSGGeometry_AttributeSet.ctd_base,
    &enumTypes[23].etd_base,
    &sipTypeDef_QtQuick_QSGGeometry_ColoredPoint2D.ctd_base,
    &enumTypes[24].etd_base,
    &enumTypes[22].etd_base,
    &sipTypeDef_QtQuick_QSGGeometry_Point2D.ctd_base,
    &sipTypeDef_QtQuick_QSGGeometry_TexturedPoint2D.ctd_base,
    &enumTypes[21].etd_base,
    &sipTypeDef_QtQuick_QSGGeometryNode.ctd_base,
    &sipTypeDef_QtQuick_QSGImageNode.ctd_base,
    &enumTypes[20].etd_base,
    &sipTypeDef_QtQuick_QSGImageNode_TextureCoordinatesTransformMode.ctd_base,
    &sipTypeDef_QtQuick_QSGMaterial.ctd_base,
    &enumTypes[18].etd_base,
    &sipTypeDef_QtQuick_QSGMaterial_Flags.ctd_base,
    &sipTypeDef_QtQuick_QSGMaterialRhiShader.ctd_base,
    &enumTypes[14].etd_base,
    &sipTypeDef_QtQuick_QSGMaterialRhiShader_Flags.ctd_base,
    &sipTypeDef_QtQuick_QSGMaterialRhiShader_GraphicsPipelineState.ctd_base,
    &enumTypes[17].etd_base,
    &sipTypeDef_QtQuick_QSGMaterialRhiShader_GraphicsPipelineState_ColorMask.ctd_base,
    &enumTypes[16].etd_base,
    &enumTypes[15].etd_base,
    &sipTypeDef_QtQuick_QSGMaterialRhiShader_RenderState.ctd_base,
    &sipTypeDef_QtQuick_QSGMaterialShader.ctd_base,
    &sipTypeDef_QtQuick_QSGMaterialShader_RenderState.ctd_base,
    &enumTypes[19].etd_base,
    &sipTypeDef_QtQuick_QSGMaterialShader_RenderState_DirtyStates.ctd_base,
    &sipTypeDef_QtQuick_QSGMaterialType.ctd_base,
    &sipTypeDef_QtQuick_QSGNode.ctd_base,
    &sipTypeDef_QtQuick_QSGNode_DirtyState.ctd_base,
    &enumTypes[11].etd_base,
    &enumTypes[12].etd_base,
    &sipTypeDef_QtQuick_QSGNode_Flags.ctd_base,
    &enumTypes[13].etd_base,
    &sipTypeDef_QtQuick_QSGOpacityNode.ctd_base,
    &sipTypeDef_QtQuick_QSGOpaqueTextureMaterial.ctd_base,
    &sipTypeDef_QtQuick_QSGRectangleNode.ctd_base,
    &sipTypeDef_QtQuick_QSGRenderNode.ctd_base,
    &sipTypeDef_QtQuick_QSGRenderNode_RenderState.ctd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtQuick_QSGRenderNode_RenderingFlags.ctd_base,
    &enumTypes[5].etd_base,
    &sipTypeDef_QtQuick_QSGRenderNode_StateFlags.ctd_base,
    &sipTypeDef_QtQuick_QSGRendererInterface.ctd_base,
    &enumTypes[10].etd_base,
    &enumTypes[9].etd_base,
    &enumTypes[7].etd_base,
    &sipTypeDef_QtQuick_QSGRendererInterface_ShaderCompilationTypes.ctd_base,
    &enumTypes[6].etd_base,
    &sipTypeDef_QtQuick_QSGRendererInterface_ShaderSourceTypes.ctd_base,
    &enumTypes[8].etd_base,
    &sipTypeDef_QtQuick_QSGSimpleRectNode.ctd_base,
    &sipTypeDef_QtQuick_QSGSimpleTextureNode.ctd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_QtQuick_QSGSimpleTextureNode_TextureCoordinatesTransformMode.ctd_base,
    &sipTypeDef_QtQuick_QSGTexture.ctd_base,
    &enumTypes[0].etd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtQuick_QSGTexture_NativeTexture.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtQuick_QSGTextureMaterial.ctd_base,
    &sipTypeDef_QtQuick_QSGTextureProvider.ctd_base,
    &sipTypeDef_QtQuick_QSGTransformNode.ctd_base,
    &sipTypeDef_QtQuick_QSGVertexColorMaterial.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"QSGMaterialRhiShader::RenderState::DirtyStates", "QSGMaterialShader::RenderState::DirtyStates"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtQuick_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QEvent"},
    {"QMetaMethod"},
    {"QObject"},
    {"QPoint"},
    {"QPointF"},
    {"QRect"},
    {"QRectF"},
    {"QRunnable"},
    {"QSize"},
    {"QSizeF"},
    {"QString"},
    {"QStringList"},
    {"QThread"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {"QVariantMap"},
    {"QVector<int>"},
    {"Qt::FocusReason"},
    {"Qt::InputMethodQueries"},
    {"Qt::InputMethodQuery"},
    {"Qt::MouseButtons"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtQuick_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtQml. */
sipImportedTypeDef sipImportedTypes_QtQuick_QtQml[] = {
    {"QList<QQmlError>"},
    {"QQmlContext"},
    {"QQmlEngine"},
    {"QQmlImageProviderBase"},
    {"QQmlImageProviderBase::Flags"},
    {"QQmlImageProviderBase::ImageType"},
    {"QQmlIncubationController"},
    {"QQmlParserStatus"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_QtQuick_QtGui[] = {
    {"QColor"},
    {"QCursor"},
    {"QDragEnterEvent"},
    {"QDragLeaveEvent"},
    {"QDragMoveEvent"},
    {"QDropEvent"},
    {"QExposeEvent"},
    {"QFocusEvent"},
    {"QHideEvent"},
    {"QHoverEvent"},
    {"QImage"},
    {"QInputMethodEvent"},
    {"QKeyEvent"},
    {"QMatrix4x4"},
    {"QMouseEvent"},
    {"QMoveEvent"},
    {"QOpenGLContext"},
    {"QOpenGLFramebufferObject"},
    {"QOpenGLShader::ShaderType"},
    {"QOpenGLShaderProgram"},
    {"QPainter"},
    {"QPixmap"},
    {"QRegion"},
    {"QResizeEvent"},
    {"QShowEvent"},
    {"QSurface"},
    {"QSurface::SurfaceType"},
    {"QSurfaceFormat"},
    {"QTabletEvent"},
    {"QTextDocument"},
    {"QTouchEvent"},
    {"QWheelEvent"},
    {"QWindow"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtQuick_QtCore, sipImportedVirtErrorHandlers_QtQuick_QtCore, SIP_NULLPTR},
    {"PyQt5.QtNetwork", SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.QtQml", sipImportedTypes_QtQuick_QtQml, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_QtQuick_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QQuickWindow, {4, 0, 0}, SIP_NULLPTR},
    {sipSubClass_QSGNode, {75, 255, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtQuick = {
    0,
    SIP_API_MINOR_NR,
    sipNameNr_PyQt5_QtQuick,
    0,
    sipStrings_QtQuick,
    importsTable,
    SIP_NULLPTR,
    111,
    sipExportedTypes_QtQuick,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    1,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtQuick;

sip_qt_metaobject_func sip_QtQuick_qt_metaobject;
sip_qt_metacall_func sip_QtQuick_qt_metacall;
sip_qt_metacast_func sip_QtQuick_qt_metacast;


/* The Python module initialisation function. */
#if PY_MAJOR_VERSION >= 3
#define SIP_MODULE_ENTRY        PyInit_QtQuick
#define SIP_MODULE_TYPE         PyObject *
#define SIP_MODULE_DISCARD(r)   Py_DECREF(r)
#define SIP_MODULE_RETURN(r)    return (r)
#else
#define SIP_MODULE_ENTRY        initQtQuick
#define SIP_MODULE_TYPE         void
#define SIP_MODULE_DISCARD(r)
#define SIP_MODULE_RETURN(r)    return
#endif

#if defined(SIP_STATIC_MODULE)
extern "C" SIP_MODULE_TYPE SIP_MODULE_ENTRY()
#else
PyMODINIT_FUNC SIP_MODULE_ENTRY()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };

#if PY_MAJOR_VERSION >= 3
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtQuick",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };
#endif

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
#if PY_MAJOR_VERSION >= 3
    sipModule = PyModule_Create(&sip_module_def);
#elif PY_VERSION_HEX >= 0x02050000
    sipModule = Py_InitModule(sipName_PyQt5_QtQuick, sip_methods);
#else
    sipModule = Py_InitModule(const_cast<char *>(sipName_PyQt5_QtQuick), sip_methods);
#endif

    if (sipModule == SIP_NULLPTR)
        SIP_MODULE_RETURN(SIP_NULLPTR);

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
#if PY_VERSION_HEX >= 0x02050000
    sip_sipmod = PyImport_ImportModule("PyQt5.sip");
#else
    sip_sipmod = PyImport_ImportModule(const_cast<char *>("PyQt5.sip"));
#endif

    if (sip_sipmod == SIP_NULLPTR)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

#if defined(SIP_USE_PYCAPSULE)
    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
#else
    if (sip_capiobj == SIP_NULLPTR || !PyCObject_Check(sip_capiobj))
#endif
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }

#if defined(SIP_USE_PYCAPSULE)
    sipAPI_QtQuick = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));
#else
    sipAPI_QtQuick = reinterpret_cast<const sipAPIDef *>(PyCObject_AsVoidPtr(sip_capiobj));
#endif

#if defined(SIP_USE_PYCAPSULE)
    if (sipAPI_QtQuick == SIP_NULLPTR)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }
#endif

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtQuick,SIP_API_MAJOR_NR,SIP_API_MINOR_NR,0) < 0)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }

    sip_QtQuick_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtQuick_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtQuick_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtQuick_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtQuick,sipModuleDict) < 0)
    {
        SIP_MODULE_DISCARD(sipModule);
        SIP_MODULE_RETURN(SIP_NULLPTR);
    }
#line 320 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtQuick/qquickwindow.sip"
qpyquick_post_init();
#line 3032 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtQuick/sipQtQuickcmodule.cpp"

    SIP_MODULE_RETURN(sipModule);
}
